/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_vSwell.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_vSwell *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_vSwell_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwell));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwell(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_vSwell_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwell));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwell(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_vSwell_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_vSwell();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_vSwell::Heavy_vSwell(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sTabwrite_init(&sTabwrite_cQPCAYzz, &hTable_e2VlguIB);
  numBytes += sTabread_init(&sTabread_umJfhoal, &hTable_e2VlguIB, true);
  numBytes += sRPole_init(&sRPole_osqG9y32);
  numBytes += sEnv_init(&sEnv_T31G0PE4, 1024, 512);
  numBytes += sLine_init(&sLine_9IcnkkSe);
  numBytes += cSlice_init(&cSlice_w0ahdL25, 1, -1);
  numBytes += cSlice_init(&cSlice_MeSH8Nuv, 1, -1);
  numBytes += cVar_init_f(&cVar_gOEDkKji, 0.0f);
  numBytes += cIf_init(&cIf_DjmjTIDB, false);
  numBytes += cBinop_init(&cBinop_3oER83tK, 0.0f); // __neq
  numBytes += cSlice_init(&cSlice_4kAtqeA0, 1, -1);
  numBytes += cSlice_init(&cSlice_UMKcR3nz, 1, -1);
  numBytes += cVar_init_f(&cVar_FPlT1gLN, 0.0f);
  numBytes += cIf_init(&cIf_SDsQlokW, false);
  numBytes += cBinop_init(&cBinop_LUgGdwhC, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_CY1eMojw, 0.0f);
  numBytes += cVar_init_f(&cVar_8gYnzWpU, 0.0f);
  numBytes += cBinop_init(&cBinop_8VVM4uYx, 0.0f); // __gt
  numBytes += cBinop_init(&cBinop_VpJroZSW, 0.0f); // __lt
  numBytes += cSlice_init(&cSlice_45ahIRsu, 2, 1);
  numBytes += cSlice_init(&cSlice_OpUurpT8, 1, 1);
  numBytes += cSlice_init(&cSlice_TjJkXUt1, 0, 1);
  numBytes += cVar_init_f(&cVar_HE3HKTy1, 0.0f);
  numBytes += cIf_init(&cIf_txGjtadU, false);
  numBytes += cIf_init(&cIf_32bey8uE, false);
  numBytes += cIf_init(&cIf_jSlpMiPQ, false);
  numBytes += cIf_init(&cIf_Noi8K59G, false);
  numBytes += cIf_init(&cIf_rAe17J6t, false);
  numBytes += cBinop_init(&cBinop_HjdWib0U, 0.0f); // __eq
  numBytes += cDelay_init(this, &cDelay_p6NtQ3Rw, 10.0f);
  numBytes += cPack_init(&cPack_y404PPEl, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_2kkhVXyU, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_wtgJcArU, 10.0f);
  numBytes += cPack_init(&cPack_QRBuVMPc, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_88dymUsv, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_Y2UYPYzV, 10.0f);
  numBytes += cPack_init(&cPack_fgEMohH8, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_xoE8eLqT, 1e-07f);
  numBytes += cIf_init(&cIf_agJIJ7nh, true);
  numBytes += cVar_init_f(&cVar_BHhHyKZa, 1e-07f);
  numBytes += cVar_init_f(&cVar_NyQPYR1j, 1e-07f);
  numBytes += sVarf_init(&sVarf_zJoZITOA, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_PkzulCAn, 0.0f);
  numBytes += cVar_init_f(&cVar_piHEPPVQ, 20.0f);
  numBytes += cBinop_init(&cBinop_a9o6Zamj, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_M826GZJK, 0.0f);
  numBytes += cSlice_init(&cSlice_N2yj6L3c, 1, -1);
  numBytes += cSlice_init(&cSlice_2Br5HVSc, 1, -1);
  numBytes += cVar_init_f(&cVar_FXbyYbBp, 0.0f);
  numBytes += cVar_init_f(&cVar_yYu5tHFf, 20.0f);
  numBytes += cVar_init_f(&cVar_DvZRv6Hc, 0.0f);
  numBytes += cVar_init_f(&cVar_ADxloYpk, 0.0f);
  numBytes += cVar_init_f(&cVar_vHzhSvPP, 0.0f);
  numBytes += cSlice_init(&cSlice_jIGpby8b, 1, 1);
  numBytes += cSlice_init(&cSlice_cZywUBDu, 0, 1);
  numBytes += cBinop_init(&cBinop_bj4vOguS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Af9Z3T0Y, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XKpaUGZU, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_iotFeLot, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_r7jYV4qq, 20.0f); // __div
  numBytes += cBinop_init(&cBinop_Eh3R1GOT, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_ToRCks74, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_FsiWqfZP, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_rv1HR0Jv, 5.0f);
  numBytes += cVar_init_f(&cVar_csQrirqX, 500.0f);
  numBytes += cBinop_init(&cBinop_PrAoTTGJ, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_KNzo41dC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LZTxA3pq, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_BR7qCZeh, 0.0f);
  numBytes += cDelay_init(this, &cDelay_bmYfyFeH, 0.0f);
  numBytes += hTable_init(&hTable_e2VlguIB, 256);
  numBytes += cTabhead_init(&cTabhead_M1zeeSad, &hTable_e2VlguIB);
  numBytes += cVar_init_s(&cVar_ufz4pa31, "del-1001-swell");
  numBytes += cDelay_init(this, &cDelay_2hD8WyvD, 8.0f);
  numBytes += cDelay_init(this, &cDelay_pKpCz0st, 0.0f);
  numBytes += cBinop_init(&cBinop_fs5EgyLE, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_EKX81fDH, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_U7sK1d5d, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_50Yj47kG, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_RiYXP8FL, 2.0f); // __sub
  numBytes += sVarf_init(&sVarf_2op7mIUE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zJDABEC0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LwOV0hAO, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_vSwell::~Heavy_vSwell() {
  sEnv_free(&sEnv_T31G0PE4);
  cPack_free(&cPack_y404PPEl);
  cPack_free(&cPack_QRBuVMPc);
  cPack_free(&cPack_fgEMohH8);
  hTable_free(&hTable_e2VlguIB);
}

HvTable *Heavy_vSwell::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xB4039215: return &hTable_e2VlguIB; // del-1001-swell
    default: return nullptr;
  }
}

void Heavy_vSwell::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xCFF35931: { // Attack_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tRbj4SMj_sendMessage);
      break;
    }
    case 0x4397AE0: { // Attack_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nddMsByM_sendMessage);
      break;
    }
    case 0x73ACB90E: { // Mid_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3z7GZLtK_sendMessage);
      break;
    }
    case 0x4675584E: { // Mid_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jpsj1RGG_sendMessage);
      break;
    }
    case 0x558F437A: { // Release_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_F185uDJZ_sendMessage);
      break;
    }
    case 0x8D204657: { // Shape
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_k7VDdWQi_sendMessage);
      break;
    }
    case 0x2D669F6F: { // SubEnv_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KuoAdXqV_sendMessage);
      break;
    }
    case 0x7BABB594: { // Threshold_High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vjKfpaXO_sendMessage);
      break;
    }
    case 0xA0E82E9F: { // Threshold_Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_B5B02Iq8_sendMessage);
      break;
    }
    case 0x145892E8: { // Threshold_Strict
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Uhj0ystu_sendMessage);
      break;
    }
    case 0xCB36B160: { // Trigger_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8C4iBVQ8_sendMessage);
      break;
    }
    case 0x5DF5B524: { // Trigger_EXT
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QU1V7byQ_sendMessage);
      break;
    }
    case 0xE7A7BB75: { // Trigger_by_Audio_ON
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gFh7MS1q_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KJi2uqMC_sendMessage);
      break;
    }
    case 0x67E37CA3: { // __hv_notein
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cqT80kCq_sendMessage);
      break;
    }
    case 0xA2F0F2D3: { // ecancel
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zfcCAubr_sendMessage);
      break;
    }
    case 0xC698CFF8: { // subenv
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_phaRb0Rc_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_vSwell::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Attack_Level";
        info->hash = 0xCFF35931;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.6f;
        break;
      }
      case 1: {
        info->name = "Attack_ms";
        info->hash = 0x4397AE0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 3000.0f;
        info->defaultVal = 400.0f;
        break;
      }
      case 2: {
        info->name = "Mid_Level";
        info->hash = 0x73ACB90E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.65f;
        break;
      }
      case 3: {
        info->name = "Mid_ms";
        info->hash = 0x4675584E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 4: {
        info->name = "Release_ms";
        info->hash = 0x558F437A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 2200.0f;
        break;
      }
      case 5: {
        info->name = "Shape";
        info->hash = 0x8D204657;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.1f;
        info->maxVal = 3.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 6: {
        info->name = "SubEnv_Level";
        info->hash = 0x2D669F6F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1e-07f;
        info->maxVal = 0.7f;
        info->defaultVal = 1e-07f;
        break;
      }
      case 7: {
        info->name = "Threshold_High";
        info->hash = 0x7BABB594;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 30.0f;
        info->maxVal = 85.0f;
        info->defaultVal = 52.0f;
        break;
      }
      case 8: {
        info->name = "Threshold_Low";
        info->hash = 0xA0E82E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.3f;
        info->maxVal = 8.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 9: {
        info->name = "Threshold_Strict";
        info->hash = 0x145892E8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "Trigger_Delay";
        info->hash = 0xCB36B160;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 50.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 11: {
        info->name = "Trigger_EXT";
        info->hash = 0x5DF5B524;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Trigger_by_Audio_ON";
        info->hash = 0xE7A7BB75;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 13;
}



/*
 * Send Function Implementations
 */


void Heavy_vSwell::sEnv_T31G0PE4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8VVM4uYx, HV_BINOP_GREATER_THAN, 0, m, &cBinop_8VVM4uYx_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VpJroZSW, HV_BINOP_LESS_THAN, 0, m, &cBinop_VpJroZSW_sendMessage);
}

void Heavy_vSwell::cSwitchcase_4LdaKKJy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_w0ahdL25, 0, m, &cSlice_w0ahdL25_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MeSH8Nuv, 0, m, &cSlice_MeSH8Nuv_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VtZRhPhh_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c4fJwuNx_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_w0ahdL25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_gOEDkKji, 0, m, &cVar_gOEDkKji_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_gOEDkKji, 0, m, &cVar_gOEDkKji_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_MeSH8Nuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_3oER83tK, HV_BINOP_NEQ, 1, m, &cBinop_3oER83tK_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_gOEDkKji, 1, m, &cVar_gOEDkKji_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_3oER83tK, HV_BINOP_NEQ, 1, m, &cBinop_3oER83tK_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_gOEDkKji, 1, m, &cVar_gOEDkKji_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_gOEDkKji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7dZESJRd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cIf_DjmjTIDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_084NcUU7_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QE4OJLo9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cCast_084NcUU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3oER83tK, HV_BINOP_NEQ, 1, m, &cBinop_3oER83tK_sendMessage);
}

void Heavy_vSwell::cCast_QE4OJLo9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gOEDkKji, 0, m, &cVar_gOEDkKji_sendMessage);
}

void Heavy_vSwell::cBinop_3oER83tK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DjmjTIDB, 1, m, &cIf_DjmjTIDB_sendMessage);
}

void Heavy_vSwell::cCast_c4fJwuNx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DjmjTIDB, 0, m, &cIf_DjmjTIDB_sendMessage);
}

void Heavy_vSwell::cCast_VtZRhPhh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3oER83tK, HV_BINOP_NEQ, 0, m, &cBinop_3oER83tK_sendMessage);
}

void Heavy_vSwell::cSwitchcase_yU8XmJ6c_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4kAtqeA0, 0, m, &cSlice_4kAtqeA0_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UMKcR3nz, 0, m, &cSlice_UMKcR3nz_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a8f8jmFd_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x9xrclgx_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_4kAtqeA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_FPlT1gLN, 0, m, &cVar_FPlT1gLN_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_FPlT1gLN, 0, m, &cVar_FPlT1gLN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_UMKcR3nz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_LUgGdwhC, HV_BINOP_NEQ, 1, m, &cBinop_LUgGdwhC_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_FPlT1gLN, 1, m, &cVar_FPlT1gLN_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_LUgGdwhC, HV_BINOP_NEQ, 1, m, &cBinop_LUgGdwhC_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_FPlT1gLN, 1, m, &cVar_FPlT1gLN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_FPlT1gLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_c7lw3FUM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cIf_SDsQlokW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6Nb3mNKj_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wy3rlVNI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cCast_Wy3rlVNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FPlT1gLN, 0, m, &cVar_FPlT1gLN_sendMessage);
}

void Heavy_vSwell::cCast_6Nb3mNKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LUgGdwhC, HV_BINOP_NEQ, 1, m, &cBinop_LUgGdwhC_sendMessage);
}

void Heavy_vSwell::cBinop_LUgGdwhC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SDsQlokW, 1, m, &cIf_SDsQlokW_sendMessage);
}

void Heavy_vSwell::cCast_a8f8jmFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LUgGdwhC, HV_BINOP_NEQ, 0, m, &cBinop_LUgGdwhC_sendMessage);
}

void Heavy_vSwell::cCast_x9xrclgx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SDsQlokW, 0, m, &cIf_SDsQlokW_sendMessage);
}

void Heavy_vSwell::cSwitchcase_7dZESJRd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h5Voq0PL_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aZ1nMuQk_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_h5Voq0PL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8gYnzWpU, 0, m, &cVar_8gYnzWpU_sendMessage);
}

void Heavy_vSwell::cCast_aZ1nMuQk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u0cw5mGI_sendMessage(_c, 0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_agJIJ7nh, 0, m, &cIf_agJIJ7nh_sendMessage);
}

void Heavy_vSwell::cSwitchcase_c7lw3FUM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fzlJjT29_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E92oi5NK_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_fzlJjT29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CY1eMojw, 0, m, &cVar_CY1eMojw_sendMessage);
}

void Heavy_vSwell::cCast_E92oi5NK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aV3RvdZ0_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_CY1eMojw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8VVM4uYx, HV_BINOP_GREATER_THAN, 1, m, &cBinop_8VVM4uYx_sendMessage);
}

void Heavy_vSwell::cVar_8gYnzWpU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VpJroZSW, HV_BINOP_LESS_THAN, 1, m, &cBinop_VpJroZSW_sendMessage);
}

void Heavy_vSwell::cBinop_8VVM4uYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4LdaKKJy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cBinop_VpJroZSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_yU8XmJ6c_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_u0cw5mGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8VVM4uYx, HV_BINOP_GREATER_THAN, 1, m, &cBinop_8VVM4uYx_sendMessage);
}

void Heavy_vSwell::cMsg_aV3RvdZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, -1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VpJroZSW, HV_BINOP_LESS_THAN, 1, m, &cBinop_VpJroZSW_sendMessage);
}

void Heavy_vSwell::cSlice_45ahIRsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_GcMHhlNq_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_OpUurpT8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_Noi8K59G, 0, m, &cIf_Noi8K59G_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_32bey8uE, 0, m, &cIf_32bey8uE_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_TjJkXUt1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_rAe17J6t, 0, m, &cIf_rAe17J6t_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_jSlpMiPQ, 0, m, &cIf_jSlpMiPQ_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_HE3HKTy1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_xgH4VqYv_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_txGjtadU, 0, m, &cIf_txGjtadU_sendMessage);
}

void Heavy_vSwell::cUnop_aqlWlJeU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tjeZR9xK_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HjdWib0U, HV_BINOP_EQ, 1, m, &cBinop_HjdWib0U_sendMessage);
}

void Heavy_vSwell::cUnop_pYb2ajgf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tjeZR9xK_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HjdWib0U, HV_BINOP_EQ, 1, m, &cBinop_HjdWib0U_sendMessage);
}

void Heavy_vSwell::cIf_txGjtadU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_pYb2ajgf_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_aqlWlJeU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_xgH4VqYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_txGjtadU, 1, m, &cIf_txGjtadU_sendMessage);
}

void Heavy_vSwell::cIf_32bey8uE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5uqkcrqI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_jSlpMiPQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_Noi8K59G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5uqkcrqI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_rAe17J6t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_GcMHhlNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HjdWib0U, HV_BINOP_EQ, 0, m, &cBinop_HjdWib0U_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_L3KnjMiD_sendMessage);
}

void Heavy_vSwell::cBinop_tjeZR9xK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OVHhBNs0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SGKyyphl_sendMessage);
}

void Heavy_vSwell::cBinop_HjdWib0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5tMm7MhM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z5gESU3E_sendMessage);
}

void Heavy_vSwell::cCast_Z5gESU3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rAe17J6t, 1, m, &cIf_rAe17J6t_sendMessage);
}

void Heavy_vSwell::cCast_5tMm7MhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_32bey8uE, 1, m, &cIf_32bey8uE_sendMessage);
}

void Heavy_vSwell::cCast_SGKyyphl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jSlpMiPQ, 1, m, &cIf_jSlpMiPQ_sendMessage);
}

void Heavy_vSwell::cCast_OVHhBNs0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Noi8K59G, 1, m, &cIf_Noi8K59G_sendMessage);
}

void Heavy_vSwell::cBinop_L3KnjMiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_vSwell::cSwitchcase_Aj6piSbd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_W1XBB8mx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_W1XBB8mx_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_p6NtQ3Rw, 1, m, &cDelay_p6NtQ3Rw_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MGlO3xfQ_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_p6NtQ3Rw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_p6NtQ3Rw, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NcICFTGT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CzvMXcMI_sendMessage);
  cSwitchcase_phrJBYJl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_W1XBB8mx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_p6NtQ3Rw, 0, m, &cDelay_p6NtQ3Rw_sendMessage);
}

void Heavy_vSwell::cCast_MGlO3xfQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_p6NtQ3Rw, 0, m, &cDelay_p6NtQ3Rw_sendMessage);
}

void Heavy_vSwell::cPack_y404PPEl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lso0S6GO_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_2kkhVXyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kcdLDv56_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_t4GBg7tk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_Aj6piSbd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_a700JTba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_y404PPEl, 0, m, &cPack_y404PPEl_sendMessage);
}

void Heavy_vSwell::cCast_XzKf60pp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2kkhVXyU, 0, m, &cVar_2kkhVXyU_sendMessage);
}

void Heavy_vSwell::cMsg_kcdLDv56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_9IcnkkSe, 0, m, NULL);
}

void Heavy_vSwell::cMsg_lso0S6GO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_9IcnkkSe, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_phrJBYJl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_xNeDpjvB_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_xNeDpjvB_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wtgJcArU, 1, m, &cDelay_wtgJcArU_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UY11VTt7_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_wtgJcArU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wtgJcArU, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iACNwZF4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a25XmvI0_sendMessage);
  cSwitchcase_1NJUbVtK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_xNeDpjvB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wtgJcArU, 0, m, &cDelay_wtgJcArU_sendMessage);
}

void Heavy_vSwell::cCast_UY11VTt7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wtgJcArU, 0, m, &cDelay_wtgJcArU_sendMessage);
}

void Heavy_vSwell::cPack_QRBuVMPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ha4tuiNe_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_88dymUsv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wvqoVCrn_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_VNIXUqd7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_phrJBYJl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_CzvMXcMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_QRBuVMPc, 0, m, &cPack_QRBuVMPc_sendMessage);
}

void Heavy_vSwell::cCast_NcICFTGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_88dymUsv, 0, m, &cVar_88dymUsv_sendMessage);
}

void Heavy_vSwell::cMsg_wvqoVCrn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_9IcnkkSe, 0, m, NULL);
}

void Heavy_vSwell::cMsg_ha4tuiNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_9IcnkkSe, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_1NJUbVtK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_b6od5u1s_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_b6od5u1s_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Y2UYPYzV, 1, m, &cDelay_Y2UYPYzV_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gAQsg1mt_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_Y2UYPYzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Y2UYPYzV, m);
}

void Heavy_vSwell::cMsg_b6od5u1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y2UYPYzV, 0, m, &cDelay_Y2UYPYzV_sendMessage);
}

void Heavy_vSwell::cCast_gAQsg1mt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y2UYPYzV, 0, m, &cDelay_Y2UYPYzV_sendMessage);
}

void Heavy_vSwell::cPack_fgEMohH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mq9FMFzT_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_xoE8eLqT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Pm2fG1nG_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_CYVXYMBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_1NJUbVtK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_iACNwZF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xoE8eLqT, 0, m, &cVar_xoE8eLqT_sendMessage);
}

void Heavy_vSwell::cCast_a25XmvI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_fgEMohH8, 0, m, &cPack_fgEMohH8_sendMessage);
}

void Heavy_vSwell::cMsg_Pm2fG1nG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_9IcnkkSe, 0, m, NULL);
}

void Heavy_vSwell::cMsg_mq9FMFzT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_9IcnkkSe, 0, m, NULL);
}

void Heavy_vSwell::cIf_agJIJ7nh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EWwBjoOX_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A7C4ygmA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSwitchcase_eLI7VjIB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ptqMBzcq_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_ptqMBzcq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EWwBjoOX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A7C4ygmA_sendMessage);
}

void Heavy_vSwell::cVar_BHhHyKZa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9M7GioOv_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_NyQPYR1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_fgEMohH8, 1, m, &cPack_fgEMohH8_sendMessage);
}

void Heavy_vSwell::cMsg_3uT1fVZ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UBnCCRUX_sendMessage);
}

void Heavy_vSwell::cSystem_UBnCCRUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Af9Z3T0Y, HV_BINOP_MULTIPLY, 1, m, &cBinop_Af9Z3T0Y_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bj4vOguS, HV_BINOP_MULTIPLY, 1, m, &cBinop_bj4vOguS_sendMessage);
}

void Heavy_vSwell::cSwitchcase_PRGUYeMd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_9Q2R4bbs_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_9Q2R4bbs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Xhj3yPLr_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_PkzulCAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PkzulCAn, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PkzulCAn, 0, m, &cDelay_PkzulCAn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_M826GZJK, 0, m, &cVar_M826GZJK_sendMessage);
}

void Heavy_vSwell::cCast_Xhj3yPLr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9Q2R4bbs_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PkzulCAn, 0, m, &cDelay_PkzulCAn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_M826GZJK, 0, m, &cVar_M826GZJK_sendMessage);
}

void Heavy_vSwell::cMsg_178yR4s4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nD35q6AX_sendMessage);
}

void Heavy_vSwell::cSystem_nD35q6AX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_xt99SbPz_sendMessage);
}

void Heavy_vSwell::cVar_piHEPPVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a9o6Zamj, HV_BINOP_MULTIPLY, 0, m, &cBinop_a9o6Zamj_sendMessage);
}

void Heavy_vSwell::cMsg_9Q2R4bbs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_PkzulCAn, 0, m, &cDelay_PkzulCAn_sendMessage);
}

void Heavy_vSwell::cBinop_SiRP5zBX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PkzulCAn, 2, m, &cDelay_PkzulCAn_sendMessage);
}

void Heavy_vSwell::cBinop_xt99SbPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a9o6Zamj, HV_BINOP_MULTIPLY, 1, m, &cBinop_a9o6Zamj_sendMessage);
}

void Heavy_vSwell::cBinop_a9o6Zamj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_SiRP5zBX_sendMessage);
}

void Heavy_vSwell::cVar_M826GZJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XKpaUGZU, HV_BINOP_SUBTRACT, 0, m, &cBinop_XKpaUGZU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_LESS_THAN_EQL, 0.0f, 0, m, &cBinop_c7XDIyaa_sendMessage);
}

void Heavy_vSwell::cSwitchcase_8yhG8Cwt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_I0x8PrYL_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_banB1DQX_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_I0x8PrYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vHzhSvPP, 0, m, &cVar_vHzhSvPP_sendMessage);
}

void Heavy_vSwell::cCast_banB1DQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yTVkb6AJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JqeiFvps_sendMessage);
}

void Heavy_vSwell::cSwitchcase_ZZ9N75Jf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cSlice_onMessage(_c, &Context(_c)->cSlice_N2yj6L3c, 0, m, &cSlice_N2yj6L3c_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2Br5HVSc, 0, m, &cSlice_2Br5HVSc_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HVajsFQe_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_jIGpby8b, 0, m, &cSlice_jIGpby8b_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_cZywUBDu, 0, m, &cSlice_cZywUBDu_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5yeW8Q03_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s4S6EEoz_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_N2yj6L3c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Cgs5eLyg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cMsg_Cgs5eLyg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_2Br5HVSc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mim77DTj_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pnDQJ4mb_sendMessage);
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mim77DTj_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pnDQJ4mb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_FXbyYbBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d0QCZhBh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TRDkFhaz_sendMessage);
}

void Heavy_vSwell::cVar_yYu5tHFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BQW55kc0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_BQW55kc0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U4EDTxxb_sendMessage);
      break;
    }
    default: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Af9Z3T0Y, HV_BINOP_MULTIPLY, 0, m, &cBinop_Af9Z3T0Y_sendMessage);
      cBinop_onMessage(_c, &Context(_c)->cBinop_r7jYV4qq, HV_BINOP_DIVIDE, 1, m, &cBinop_r7jYV4qq_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_piHEPPVQ, 0, m, &cVar_piHEPPVQ_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cCast_U4EDTxxb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O3Eohl2W_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_DvZRv6Hc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FsiWqfZP, HV_BINOP_SUBTRACT, 1, m, &cBinop_FsiWqfZP_sendMessage);
}

void Heavy_vSwell::cVar_ADxloYpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vHzhSvPP, 0, m, &cVar_vHzhSvPP_sendMessage);
}

void Heavy_vSwell::cVar_vHzhSvPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iotFeLot, HV_BINOP_ADD, 0, m, &cBinop_iotFeLot_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ToRCks74, HV_BINOP_ADD, 0, m, &cBinop_ToRCks74_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_zJoZITOA, m);
}

void Heavy_vSwell::cSlice_jIGpby8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d0QCZhBh_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TRDkFhaz_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_cZywUBDu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4cbdz77c_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fK7IriJm_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_ExCsGYMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_M826GZJK, 1, m, &cVar_M826GZJK_sendMessage);
}

void Heavy_vSwell::cBinop_bj4vOguS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ExCsGYMl_sendMessage);
}

void Heavy_vSwell::cBinop_Af9Z3T0Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_xWp7sauq_sendMessage);
}

void Heavy_vSwell::cBinop_xWp7sauq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XKpaUGZU, HV_BINOP_SUBTRACT, 1, m, &cBinop_XKpaUGZU_sendMessage);
}

void Heavy_vSwell::cBinop_XKpaUGZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_M826GZJK, 1, m, &cVar_M826GZJK_sendMessage);
}

void Heavy_vSwell::cMsg_CV1qy5WJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cSwitchcase_PRGUYeMd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_xSTRxrR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_PRGUYeMd_onMessage(_c, NULL, 0, m, NULL);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ToRCks74, HV_BINOP_ADD, 1, m, &cBinop_ToRCks74_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_iotFeLot, HV_BINOP_ADD, 1, m, &cBinop_iotFeLot_sendMessage);
}

void Heavy_vSwell::cBinop_c7XDIyaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8yhG8Cwt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cBinop_iotFeLot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vHzhSvPP, 1, m, &cVar_vHzhSvPP_sendMessage);
}

void Heavy_vSwell::cBinop_r7jYV4qq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Eh3R1GOT, HV_BINOP_DIVIDE, 1, m, &cBinop_Eh3R1GOT_sendMessage);
}

void Heavy_vSwell::cBinop_Eh3R1GOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ToRCks74, HV_BINOP_ADD, 1, m, &cBinop_ToRCks74_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_iotFeLot, HV_BINOP_ADD, 1, m, &cBinop_iotFeLot_sendMessage);
}

void Heavy_vSwell::cCast_TRDkFhaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r7jYV4qq, HV_BINOP_DIVIDE, 0, m, &cBinop_r7jYV4qq_sendMessage);
}

void Heavy_vSwell::cCast_d0QCZhBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bj4vOguS, HV_BINOP_MULTIPLY, 0, m, &cBinop_bj4vOguS_sendMessage);
}

void Heavy_vSwell::cCast_fK7IriJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FsiWqfZP, HV_BINOP_SUBTRACT, 0, m, &cBinop_FsiWqfZP_sendMessage);
}

void Heavy_vSwell::cCast_4cbdz77c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ADxloYpk, 1, m, &cVar_ADxloYpk_sendMessage);
}

void Heavy_vSwell::cCast_yTVkb6AJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xSTRxrR4_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_JqeiFvps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ADxloYpk, 0, m, &cVar_ADxloYpk_sendMessage);
}

void Heavy_vSwell::cBinop_ToRCks74_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DvZRv6Hc, 0, m, &cVar_DvZRv6Hc_sendMessage);
}

void Heavy_vSwell::cMsg_Cgs5eLyg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_PRGUYeMd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_Bc7FI2T0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_FXbyYbBp, 1, m, &cVar_FXbyYbBp_sendMessage);
}

void Heavy_vSwell::cMsg_O3Eohl2W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 20.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Af9Z3T0Y, HV_BINOP_MULTIPLY, 0, m, &cBinop_Af9Z3T0Y_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_r7jYV4qq, HV_BINOP_DIVIDE, 1, m, &cBinop_r7jYV4qq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_piHEPPVQ, 0, m, &cVar_piHEPPVQ_sendMessage);
}

void Heavy_vSwell::cCast_mim77DTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Cgs5eLyg_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_pnDQJ4mb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_prkF914c_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ToRCks74, HV_BINOP_ADD, 0, m, &cBinop_ToRCks74_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vHzhSvPP, 1, m, &cVar_vHzhSvPP_sendMessage);
}

void Heavy_vSwell::cBinop_FsiWqfZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Eh3R1GOT, HV_BINOP_DIVIDE, 0, m, &cBinop_Eh3R1GOT_sendMessage);
}

void Heavy_vSwell::cCast_prkF914c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xSTRxrR4_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_s4S6EEoz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Bc7FI2T0_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_5yeW8Q03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CV1qy5WJ_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_HVajsFQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FXbyYbBp, 0, m, &cVar_FXbyYbBp_sendMessage);
}

void Heavy_vSwell::cSwitchcase_kT4xlKfT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_AAUF8kbM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_AAUF8kbM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_rv1HR0Jv, 1, m, &cDelay_rv1HR0Jv_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5YZ5Mf1L_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_rv1HR0Jv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rv1HR0Jv, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XzKf60pp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a700JTba_sendMessage);
  cSwitchcase_Aj6piSbd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_AAUF8kbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_rv1HR0Jv, 0, m, &cDelay_rv1HR0Jv_sendMessage);
}

void Heavy_vSwell::cCast_5YZ5Mf1L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rv1HR0Jv, 0, m, &cDelay_rv1HR0Jv_sendMessage);
}

void Heavy_vSwell::cVar_csQrirqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PrAoTTGJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_PrAoTTGJ_sendMessage);
}

void Heavy_vSwell::cMsg_zJFAjGsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wbSB1Q0G_sendMessage);
}

void Heavy_vSwell::cSystem_wbSB1Q0G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5b7Zir7N_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_PrAoTTGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ExqiUY06_sendMessage);
}

void Heavy_vSwell::cBinop_jSh8yQ5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PrAoTTGJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_PrAoTTGJ_sendMessage);
}

void Heavy_vSwell::cMsg_5b7Zir7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_jSh8yQ5e_sendMessage);
}

void Heavy_vSwell::cBinop_ExqiUY06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_AABPc4i0_sendMessage);
}

void Heavy_vSwell::cBinop_AABPc4i0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_pXvkApXH_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_LZTxA3pq, m);
}

void Heavy_vSwell::cBinop_pXvkApXH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_KNzo41dC, m);
}

void Heavy_vSwell::cMsg_FJ8WKEQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jComLO8L_sendMessage);
}

void Heavy_vSwell::cSystem_jComLO8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_RNavWvJP_sendMessage);
}

void Heavy_vSwell::cDelay_BR7qCZeh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BR7qCZeh, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bmYfyFeH, 0, m, &cDelay_bmYfyFeH_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BR7qCZeh, 0, m, &cDelay_BR7qCZeh_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_cQPCAYzz, 1, m, NULL);
}

void Heavy_vSwell::cDelay_bmYfyFeH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bmYfyFeH, m);
  cMsg_pxWxoFtB_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cSwitchcase_ZEl8VszJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_B458GZqi_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cBinop_OZYf8mXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WjmXqFyI_sendMessage(_c, 0, m);
}

void Heavy_vSwell::hTable_e2VlguIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tYI9hqiM_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BR7qCZeh, 2, m, &cDelay_BR7qCZeh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WxJdpZsG_sendMessage);
}

void Heavy_vSwell::cMsg_WjmXqFyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_e2VlguIB, 0, m, &hTable_e2VlguIB_sendMessage);
}

void Heavy_vSwell::cBinop_RNavWvJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_OZYf8mXt_sendMessage);
}

void Heavy_vSwell::cMsg_pxWxoFtB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_e2VlguIB, 0, m, &hTable_e2VlguIB_sendMessage);
}

void Heavy_vSwell::cCast_WxJdpZsG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BR7qCZeh, 0, m, &cDelay_BR7qCZeh_sendMessage);
}

void Heavy_vSwell::cMsg_tYI9hqiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_bmYfyFeH, 2, m, &cDelay_bmYfyFeH_sendMessage);
}

void Heavy_vSwell::cMsg_B458GZqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_cQPCAYzz, 1, m, NULL);
}

void Heavy_vSwell::cTabhead_M1zeeSad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EKX81fDH, HV_BINOP_SUBTRACT, 0, m, &cBinop_EKX81fDH_sendMessage);
}

void Heavy_vSwell::cMsg_jvRO8g0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_m2YYiwAD_sendMessage);
}

void Heavy_vSwell::cSystem_m2YYiwAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_vbTq54Ay_sendMessage);
}

void Heavy_vSwell::cVar_ufz4pa31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ASWyL58Z_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cDelay_2hD8WyvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2hD8WyvD, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pKpCz0st, 0, m, &cDelay_pKpCz0st_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_umJfhoal, 0, m, &sTabread_umJfhoal_sendMessage);
}

void Heavy_vSwell::cDelay_pKpCz0st_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pKpCz0st, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_umJfhoal, 0, m, &sTabread_umJfhoal_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pKpCz0st, 0, m, &cDelay_pKpCz0st_sendMessage);
}

void Heavy_vSwell::sTabread_umJfhoal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_50Yj47kG, HV_BINOP_SUBTRACT, 0, m, &cBinop_50Yj47kG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_fs5EgyLE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U7sK1d5d, HV_BINOP_MAX, 0, m, &cBinop_U7sK1d5d_sendMessage);
}

void Heavy_vSwell::cBinop_vbTq54Ay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fs5EgyLE, HV_BINOP_MULTIPLY, 0, m, &cBinop_fs5EgyLE_sendMessage);
}

void Heavy_vSwell::cBinop_EKX81fDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MnYn0cMV_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_umJfhoal, 0, m, &sTabread_umJfhoal_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vECehV9Z_sendMessage);
}

void Heavy_vSwell::cSystem_ErUmM6Ij_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_50Yj47kG, HV_BINOP_SUBTRACT, 1, m, &cBinop_50Yj47kG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pKpCz0st, 2, m, &cDelay_pKpCz0st_sendMessage);
}

void Heavy_vSwell::cMsg_ASWyL58Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ErUmM6Ij_sendMessage);
}

void Heavy_vSwell::cMsg_MnYn0cMV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_2hD8WyvD, 0, m, &cDelay_2hD8WyvD_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pKpCz0st, 0, m, &cDelay_pKpCz0st_sendMessage);
}

void Heavy_vSwell::cMsg_NzTLAHMm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_U7sK1d5d, HV_BINOP_MAX, 1, m, &cBinop_U7sK1d5d_sendMessage);
}

void Heavy_vSwell::cBinop_U7sK1d5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EKX81fDH, HV_BINOP_SUBTRACT, 1, m, &cBinop_EKX81fDH_sendMessage);
}

void Heavy_vSwell::cCast_vECehV9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2hD8WyvD, 0, m, &cDelay_2hD8WyvD_sendMessage);
}

void Heavy_vSwell::cBinop_NKbLJY3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2hD8WyvD, 2, m, &cDelay_2hD8WyvD_sendMessage);
}

void Heavy_vSwell::cBinop_50Yj47kG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_NKbLJY3W_sendMessage);
}

void Heavy_vSwell::cCast_osdvn73M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ufz4pa31, 0, m, &cVar_ufz4pa31_sendMessage);
  cMsg_jvRO8g0U_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_M1zeeSad, 0, m, &cTabhead_M1zeeSad_sendMessage);
}

void Heavy_vSwell::cUnop_1tRDSEVw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_zJDABEC0, m);
}

void Heavy_vSwell::cCast_A7C4ygmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kT4xlKfT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_EWwBjoOX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_m1dP5xTE_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_BHhHyKZa, 0, m, &cVar_BHhHyKZa_sendMessage);
}

void Heavy_vSwell::cCast_Cja45EoB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RiYXP8FL, HV_BINOP_SUBTRACT, 0, m, &cBinop_RiYXP8FL_sendMessage);
}

void Heavy_vSwell::cCast_621XbGWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CY1eMojw, 0, m, &cVar_CY1eMojw_sendMessage);
}

void Heavy_vSwell::cBinop_RiYXP8FL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8gYnzWpU, 0, m, &cVar_8gYnzWpU_sendMessage);
}

void Heavy_vSwell::cSend_m1dP5xTE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zfcCAubr_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_5uqkcrqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_eLI7VjIB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_UKvyDkHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 25.0f);
  cSwitchcase_ZZ9N75Jf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_9M7GioOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 3.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9IcnkkSe, 0, m, NULL);
}

void Heavy_vSwell::cSend_FqUjXJ14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_phaRb0Rc_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_wYnW3oSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rv1HR0Jv, 1, m, &cDelay_rv1HR0Jv_sendMessage);
}

void Heavy_vSwell::cBinop_IE3P2iVw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_1tRDSEVw_sendMessage);
}

void Heavy_vSwell::cReceive_B5B02Iq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RiYXP8FL, HV_BINOP_SUBTRACT, 1, m, &cBinop_RiYXP8FL_sendMessage);
}

void Heavy_vSwell::cReceive_KJi2uqMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_178yR4s4_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_piHEPPVQ, 0, m, &cVar_piHEPPVQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HE3HKTy1, 0, m, &cVar_HE3HKTy1_sendMessage);
  cMsg_3uT1fVZ3_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_DvZRv6Hc, 0, m, &cVar_DvZRv6Hc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yYu5tHFf, 0, m, &cVar_yYu5tHFf_sendMessage);
  cMsg_zJFAjGsa_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_csQrirqX, 0, m, &cVar_csQrirqX_sendMessage);
  cMsg_FJ8WKEQ0_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_NyQPYR1j, 0, m, &cVar_NyQPYR1j_sendMessage);
  cMsg_NzTLAHMm_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ufz4pa31, 0, m, &cVar_ufz4pa31_sendMessage);
  cMsg_jvRO8g0U_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_M1zeeSad, 0, m, &cTabhead_M1zeeSad_sendMessage);
}

void Heavy_vSwell::cReceive_cqT80kCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSlice_onMessage(_c, &Context(_c)->cSlice_45ahIRsu, 0, m, &cSlice_45ahIRsu_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_OpUurpT8, 0, m, &cSlice_OpUurpT8_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_TjJkXUt1, 0, m, &cSlice_TjJkXUt1_sendMessage);
}

void Heavy_vSwell::cReceive_k7VDdWQi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_2op7mIUE, m);
}

void Heavy_vSwell::cReceive_zfcCAubr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t4GBg7tk_sendMessage(_c, 0, m);
  cMsg_VNIXUqd7_sendMessage(_c, 0, m);
  cMsg_CYVXYMBf_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cReceive_vjKfpaXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Cja45EoB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_621XbGWN_sendMessage);
}

void Heavy_vSwell::cReceive_QU1V7byQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EWwBjoOX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A7C4ygmA_sendMessage);
}

void Heavy_vSwell::cReceive_gFh7MS1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_agJIJ7nh, 1, m, &cIf_agJIJ7nh_sendMessage);
}

void Heavy_vSwell::cReceive_tRbj4SMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_88dymUsv, 1, m, &cVar_88dymUsv_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_y404PPEl, 1, m, &cPack_y404PPEl_sendMessage);
}

void Heavy_vSwell::cReceive_nddMsByM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_y404PPEl, 2, m, &cPack_y404PPEl_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_p6NtQ3Rw, 1, m, &cDelay_p6NtQ3Rw_sendMessage);
}

void Heavy_vSwell::cReceive_3z7GZLtK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_QRBuVMPc, 1, m, &cPack_QRBuVMPc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xoE8eLqT, 1, m, &cVar_xoE8eLqT_sendMessage);
}

void Heavy_vSwell::cReceive_jpsj1RGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_QRBuVMPc, 2, m, &cPack_QRBuVMPc_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wtgJcArU, 1, m, &cDelay_wtgJcArU_sendMessage);
}

void Heavy_vSwell::cReceive_F185uDJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_fgEMohH8, 2, m, &cPack_fgEMohH8_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y2UYPYzV, 1, m, &cDelay_Y2UYPYzV_sendMessage);
}

void Heavy_vSwell::cReceive_phaRb0Rc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NyQPYR1j, 1, m, &cVar_NyQPYR1j_sendMessage);
  cMsg_UKvyDkHY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_BHhHyKZa, 1, m, &cVar_BHhHyKZa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2kkhVXyU, 1, m, &cVar_2kkhVXyU_sendMessage);
}

void Heavy_vSwell::cReceive_KuoAdXqV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FqUjXJ14_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cReceive_8C4iBVQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 3.0f, 0, m, &cBinop_wYnW3oSi_sendMessage);
}

void Heavy_vSwell::cReceive_Uhj0ystu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_IE3P2iVw_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_LwOV0hAO, m);
}




/*
 * Context Process Implementation
 */

int Heavy_vSwell::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4;

  // input and output vars
  hv_bufferf_t O0;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));

    // process all signal functions
    __hv_tabwrite_f(&sTabwrite_cQPCAYzz, VIf(I0));
    __hv_tabread_f(&sTabread_umJfhoal, VOf(Bf0));
    __hv_varread_f(&sVarf_LZTxA3pq, VOf(Bf1));
    __hv_mul_f(VIf(I1), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_KNzo41dC, VOf(Bf2));
    __hv_rpole_f(&sRPole_osqG9y32, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_LwOV0hAO, VOf(Bf1));
    __hv_varread_f(&sVarf_zJDABEC0, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_mul_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf3));
    __hv_gt_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_sqrt_f(VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf3), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_T31G0PE4, VIf(Bf3), &sEnv_T31G0PE4_sendMessage);
    __hv_line_f(&sLine_9IcnkkSe, VOf(Bf3));
    __hv_varread_f(&sVarf_2op7mIUE, VOf(Bf1));
    __hv_pow_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_zJoZITOA, VOf(Bf3));
    __hv_max_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf1), 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f);
    __hv_min_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf1), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_vSwell::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 1 channel(s)
  float **const bOut = &outputBuffers;

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_vSwell::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 1 channel(s)
  float *const bOut = outputBuffers;

  int n = processInline(bIn, bOut, n4);

  

  return n;
}
