/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_VSWELL_HPP_
#define _HEAVY_CONTEXT_VSWELL_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalDel1.h"
#include "HvSignalLine.h"
#include "HvSignalTabwrite.h"
#include "HvControlIf.h"
#include "HvControlPack.h"
#include "HvTable.h"
#include "HvControlUnop.h"
#include "HvSignalRPole.h"
#include "HvControlSystem.h"
#include "HvControlDelay.h"
#include "HvControlSlice.h"
#include "HvControlVar.h"
#include "HvControlBinop.h"
#include "HvMath.h"
#include "HvControlCast.h"
#include "HvSignalVar.h"
#include "HvSignalTabread.h"
#include "HvSignalEnvelope.h"
#include "HvControlTabhead.h"

class Heavy_vSwell : public HeavyContext {

 public:
  Heavy_vSwell(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_vSwell();

  const char *getName() override { return "vSwell"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 1; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        ATTACK_LEVEL = 0xCFF35931, // Attack_Level
        ATTACK_MS = 0x4397AE0, // Attack_ms
        MID_LEVEL = 0x73ACB90E, // Mid_Level
        MID_MS = 0x4675584E, // Mid_ms
        RELEASE_MS = 0x558F437A, // Release_ms
        SHAPE = 0x8D204657, // Shape
        SUBENV_LEVEL = 0x2D669F6F, // SubEnv_Level
        THRESHOLD_HIGH = 0x7BABB594, // Threshold_High
        THRESHOLD_LOW = 0xA0E82E9F, // Threshold_Low
        THRESHOLD_STRICT = 0x145892E8, // Threshold_Strict
        TRIGGER_DELAY = 0xCB36B160, // Trigger_Delay
        TRIGGER_EXT = 0x5DF5B524, // Trigger_EXT
        TRIGGER_BY_AUDIO_ON = 0xE7A7BB75, // Trigger_by_Audio_ON
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void sEnv_T31G0PE4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_4LdaKKJy_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_w0ahdL25_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_MeSH8Nuv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gOEDkKji_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_DjmjTIDB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_084NcUU7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QE4OJLo9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3oER83tK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_c4fJwuNx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VtZRhPhh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_yU8XmJ6c_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_4kAtqeA0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_UMKcR3nz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FPlT1gLN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SDsQlokW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Wy3rlVNI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6Nb3mNKj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LUgGdwhC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a8f8jmFd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_x9xrclgx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_7dZESJRd_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_h5Voq0PL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aZ1nMuQk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_c7lw3FUM_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_fzlJjT29_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_E92oi5NK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CY1eMojw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8gYnzWpU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8VVM4uYx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VpJroZSW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_u0cw5mGI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aV3RvdZ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_45ahIRsu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_OpUurpT8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_TjJkXUt1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HE3HKTy1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_aqlWlJeU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_pYb2ajgf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_txGjtadU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xgH4VqYv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_32bey8uE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jSlpMiPQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Noi8K59G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rAe17J6t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GcMHhlNq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tjeZR9xK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HjdWib0U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z5gESU3E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5tMm7MhM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SGKyyphl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OVHhBNs0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L3KnjMiD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Aj6piSbd_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_p6NtQ3Rw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W1XBB8mx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MGlO3xfQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_y404PPEl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2kkhVXyU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_t4GBg7tk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a700JTba_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XzKf60pp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kcdLDv56_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lso0S6GO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_phrJBYJl_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_wtgJcArU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xNeDpjvB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UY11VTt7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_QRBuVMPc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_88dymUsv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VNIXUqd7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CzvMXcMI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NcICFTGT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wvqoVCrn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ha4tuiNe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_1NJUbVtK_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Y2UYPYzV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b6od5u1s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gAQsg1mt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_fgEMohH8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xoE8eLqT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CYVXYMBf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iACNwZF4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a25XmvI0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Pm2fG1nG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mq9FMFzT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_agJIJ7nh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_eLI7VjIB_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_ptqMBzcq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BHhHyKZa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NyQPYR1j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3uT1fVZ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_UBnCCRUX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_PRGUYeMd_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_PkzulCAn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Xhj3yPLr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_178yR4s4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_nD35q6AX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_piHEPPVQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9Q2R4bbs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SiRP5zBX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xt99SbPz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a9o6Zamj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_M826GZJK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_8yhG8Cwt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_I0x8PrYL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_banB1DQX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ZZ9N75Jf_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_N2yj6L3c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_2Br5HVSc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FXbyYbBp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yYu5tHFf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_BQW55kc0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_U4EDTxxb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DvZRv6Hc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ADxloYpk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vHzhSvPP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_jIGpby8b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_cZywUBDu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ExCsGYMl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bj4vOguS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Af9Z3T0Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xWp7sauq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XKpaUGZU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CV1qy5WJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xSTRxrR4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c7XDIyaa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iotFeLot_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r7jYV4qq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Eh3R1GOT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TRDkFhaz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_d0QCZhBh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fK7IriJm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4cbdz77c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yTVkb6AJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JqeiFvps_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ToRCks74_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Cgs5eLyg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Bc7FI2T0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O3Eohl2W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mim77DTj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pnDQJ4mb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FsiWqfZP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_prkF914c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s4S6EEoz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5yeW8Q03_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HVajsFQe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_kT4xlKfT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_rv1HR0Jv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AAUF8kbM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5YZ5Mf1L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_csQrirqX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zJFAjGsa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_wbSB1Q0G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PrAoTTGJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jSh8yQ5e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5b7Zir7N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ExqiUY06_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AABPc4i0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pXvkApXH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FJ8WKEQ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_jComLO8L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_BR7qCZeh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_bmYfyFeH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ZEl8VszJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_OZYf8mXt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_e2VlguIB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WjmXqFyI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RNavWvJP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pxWxoFtB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WxJdpZsG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tYI9hqiM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B458GZqi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_M1zeeSad_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jvRO8g0U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_m2YYiwAD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ufz4pa31_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_2hD8WyvD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_pKpCz0st_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_umJfhoal_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fs5EgyLE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vbTq54Ay_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EKX81fDH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ErUmM6Ij_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ASWyL58Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MnYn0cMV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NzTLAHMm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U7sK1d5d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vECehV9Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NKbLJY3W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_50Yj47kG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_osdvn73M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_1tRDSEVw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_A7C4ygmA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EWwBjoOX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Cja45EoB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_621XbGWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RiYXP8FL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_m1dP5xTE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5uqkcrqI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UKvyDkHY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9M7GioOv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_FqUjXJ14_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wYnW3oSi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IE3P2iVw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_B5B02Iq8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KJi2uqMC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cqT80kCq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_k7VDdWQi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zfcCAubr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vjKfpaXO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QU1V7byQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gFh7MS1q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tRbj4SMj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nddMsByM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3z7GZLtK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jpsj1RGG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_F185uDJZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_phaRb0Rc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KuoAdXqV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8C4iBVQ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Uhj0ystu_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalTabwrite sTabwrite_cQPCAYzz;
  SignalTabread sTabread_umJfhoal;
  SignalRPole sRPole_osqG9y32;
  SignalEnvelope sEnv_T31G0PE4;
  SignalLine sLine_9IcnkkSe;
  ControlSlice cSlice_w0ahdL25;
  ControlSlice cSlice_MeSH8Nuv;
  ControlVar cVar_gOEDkKji;
  ControlIf cIf_DjmjTIDB;
  ControlBinop cBinop_3oER83tK;
  ControlSlice cSlice_4kAtqeA0;
  ControlSlice cSlice_UMKcR3nz;
  ControlVar cVar_FPlT1gLN;
  ControlIf cIf_SDsQlokW;
  ControlBinop cBinop_LUgGdwhC;
  ControlVar cVar_CY1eMojw;
  ControlVar cVar_8gYnzWpU;
  ControlBinop cBinop_8VVM4uYx;
  ControlBinop cBinop_VpJroZSW;
  ControlSlice cSlice_45ahIRsu;
  ControlSlice cSlice_OpUurpT8;
  ControlSlice cSlice_TjJkXUt1;
  ControlVar cVar_HE3HKTy1;
  ControlIf cIf_txGjtadU;
  ControlBinop cBinop_xgH4VqYv;
  ControlIf cIf_32bey8uE;
  ControlIf cIf_jSlpMiPQ;
  ControlIf cIf_Noi8K59G;
  ControlIf cIf_rAe17J6t;
  ControlBinop cBinop_GcMHhlNq;
  ControlBinop cBinop_tjeZR9xK;
  ControlBinop cBinop_HjdWib0U;
  ControlBinop cBinop_L3KnjMiD;
  ControlDelay cDelay_p6NtQ3Rw;
  ControlPack cPack_y404PPEl;
  ControlVar cVar_2kkhVXyU;
  ControlDelay cDelay_wtgJcArU;
  ControlPack cPack_QRBuVMPc;
  ControlVar cVar_88dymUsv;
  ControlDelay cDelay_Y2UYPYzV;
  ControlPack cPack_fgEMohH8;
  ControlVar cVar_xoE8eLqT;
  ControlIf cIf_agJIJ7nh;
  ControlVar cVar_BHhHyKZa;
  ControlVar cVar_NyQPYR1j;
  SignalVarf sVarf_zJoZITOA;
  ControlDelay cDelay_PkzulCAn;
  ControlVar cVar_piHEPPVQ;
  ControlBinop cBinop_SiRP5zBX;
  ControlBinop cBinop_xt99SbPz;
  ControlBinop cBinop_a9o6Zamj;
  ControlVar cVar_M826GZJK;
  ControlSlice cSlice_N2yj6L3c;
  ControlSlice cSlice_2Br5HVSc;
  ControlVar cVar_FXbyYbBp;
  ControlVar cVar_yYu5tHFf;
  ControlVar cVar_DvZRv6Hc;
  ControlVar cVar_ADxloYpk;
  ControlVar cVar_vHzhSvPP;
  ControlSlice cSlice_jIGpby8b;
  ControlSlice cSlice_cZywUBDu;
  ControlBinop cBinop_ExCsGYMl;
  ControlBinop cBinop_bj4vOguS;
  ControlBinop cBinop_Af9Z3T0Y;
  ControlBinop cBinop_xWp7sauq;
  ControlBinop cBinop_XKpaUGZU;
  ControlBinop cBinop_c7XDIyaa;
  ControlBinop cBinop_iotFeLot;
  ControlBinop cBinop_r7jYV4qq;
  ControlBinop cBinop_Eh3R1GOT;
  ControlBinop cBinop_ToRCks74;
  ControlBinop cBinop_FsiWqfZP;
  ControlDelay cDelay_rv1HR0Jv;
  ControlVar cVar_csQrirqX;
  ControlBinop cBinop_PrAoTTGJ;
  ControlBinop cBinop_jSh8yQ5e;
  SignalVarf sVarf_KNzo41dC;
  ControlBinop cBinop_ExqiUY06;
  ControlBinop cBinop_AABPc4i0;
  ControlBinop cBinop_pXvkApXH;
  SignalVarf sVarf_LZTxA3pq;
  ControlDelay cDelay_BR7qCZeh;
  ControlDelay cDelay_bmYfyFeH;
  ControlBinop cBinop_OZYf8mXt;
  HvTable hTable_e2VlguIB;
  ControlBinop cBinop_RNavWvJP;
  ControlTabhead cTabhead_M1zeeSad;
  ControlVar cVar_ufz4pa31;
  ControlDelay cDelay_2hD8WyvD;
  ControlDelay cDelay_pKpCz0st;
  ControlBinop cBinop_fs5EgyLE;
  ControlBinop cBinop_vbTq54Ay;
  ControlBinop cBinop_EKX81fDH;
  ControlBinop cBinop_U7sK1d5d;
  ControlBinop cBinop_NKbLJY3W;
  ControlBinop cBinop_50Yj47kG;
  ControlBinop cBinop_RiYXP8FL;
  ControlBinop cBinop_5uqkcrqI;
  ControlBinop cBinop_wYnW3oSi;
  ControlBinop cBinop_IE3P2iVw;
  SignalVarf sVarf_2op7mIUE;
  SignalVarf sVarf_zJDABEC0;
  SignalVarf sVarf_LwOV0hAO;
};

#endif // _HEAVY_CONTEXT_VSWELL_HPP_
