/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_vSwellST.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_vSwellST *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_vSwellST_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwellST));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwellST(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_vSwellST_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwellST));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwellST(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_vSwellST_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_vSwellST();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_vSwellST::Heavy_vSwellST(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sTabwrite_init(&sTabwrite_HzXBUYcN, &hTable_En7mSr3V);
  numBytes += sTabwrite_init(&sTabwrite_ee3hRAYU, &hTable_zGt13Z9v);
  numBytes += sRPole_init(&sRPole_1xo7QLB3);
  numBytes += sEnv_init(&sEnv_ef29TibG, 1024, 512);
  numBytes += sTabread_init(&sTabread_4qF4cmoB, &hTable_zGt13Z9v, true);
  numBytes += sLine_init(&sLine_pBq7F1MT);
  numBytes += sTabread_init(&sTabread_kIkdEv17, &hTable_En7mSr3V, true);
  numBytes += cSlice_init(&cSlice_eezjNh03, 1, -1);
  numBytes += cSlice_init(&cSlice_Eo2uFA79, 1, -1);
  numBytes += cVar_init_f(&cVar_8XUJnGiv, 0.0f);
  numBytes += cIf_init(&cIf_n2EK5mM1, false);
  numBytes += cBinop_init(&cBinop_7MRcTODj, 0.0f); // __neq
  numBytes += cSlice_init(&cSlice_oXgn5qED, 1, -1);
  numBytes += cSlice_init(&cSlice_HrGIsvBs, 1, -1);
  numBytes += cVar_init_f(&cVar_IAdyrz32, 0.0f);
  numBytes += cIf_init(&cIf_67ROVOQQ, false);
  numBytes += cBinop_init(&cBinop_dDRTG1e6, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_vLtcr2oE, 0.0f);
  numBytes += cVar_init_f(&cVar_VJ4p4K4r, 0.0f);
  numBytes += cBinop_init(&cBinop_Jm7bDQku, 0.0f); // __gt
  numBytes += cBinop_init(&cBinop_5rK7LGYk, 0.0f); // __lt
  numBytes += cSlice_init(&cSlice_lBaZtCwz, 2, 1);
  numBytes += cSlice_init(&cSlice_iy8MI4y8, 1, 1);
  numBytes += cSlice_init(&cSlice_clcmUKHM, 0, 1);
  numBytes += cVar_init_f(&cVar_P5uwOQZo, 0.0f);
  numBytes += cIf_init(&cIf_VP9p7aro, false);
  numBytes += cIf_init(&cIf_auNRyOoz, false);
  numBytes += cIf_init(&cIf_GNKHeRXH, false);
  numBytes += cIf_init(&cIf_oOI1BQnd, false);
  numBytes += cIf_init(&cIf_pU9sITTa, false);
  numBytes += cBinop_init(&cBinop_PzQMmVos, 0.0f); // __eq
  numBytes += cDelay_init(this, &cDelay_5cakV7JD, 10.0f);
  numBytes += cPack_init(&cPack_9BqThvxL, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_O7b3QRmX, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_MzfkuPVe, 10.0f);
  numBytes += cPack_init(&cPack_Smm7eHNK, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_IBZry0jz, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_g3z2YjYP, 10.0f);
  numBytes += cPack_init(&cPack_2yxVP2h9, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_WLTUsyeT, 1e-07f);
  numBytes += cVar_init_f(&cVar_PjgkuLcu, 1e-07f);
  numBytes += cVar_init_f(&cVar_QvApkUNX, 1e-07f);
  numBytes += sVarf_init(&sVarf_taCnmZ9g, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_XpkycLab, 0.0f);
  numBytes += cVar_init_f(&cVar_tiGpKop4, 20.0f);
  numBytes += cBinop_init(&cBinop_N7Fu4iSp, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_W7afLeXM, 0.0f);
  numBytes += cSlice_init(&cSlice_hQh495rv, 1, -1);
  numBytes += cSlice_init(&cSlice_z7aEC4Ne, 1, -1);
  numBytes += cVar_init_f(&cVar_GWewDSsR, 0.0f);
  numBytes += cVar_init_f(&cVar_rdjMHrbs, 20.0f);
  numBytes += cVar_init_f(&cVar_duL4D7kA, 0.0f);
  numBytes += cVar_init_f(&cVar_hOU5BSWe, 0.0f);
  numBytes += cVar_init_f(&cVar_sRWWnp7j, 0.0f);
  numBytes += cSlice_init(&cSlice_neB6MhMy, 1, 1);
  numBytes += cSlice_init(&cSlice_a5nUNzl5, 0, 1);
  numBytes += cBinop_init(&cBinop_lPK3ofP2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QAPJoy2S, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kMHSrlSn, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_AxfnC6xF, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_YekjLSIg, 20.0f); // __div
  numBytes += cBinop_init(&cBinop_4weB9V2n, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_UZhieM7x, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_O2jVewUs, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_Oa2l53Uh, 5.0f);
  numBytes += cVar_init_f(&cVar_2TwLomNj, 500.0f);
  numBytes += cBinop_init(&cBinop_iKw658hB, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_4tBFDUFj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_K9n7jQ75, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_3fJhzoVn, 0.0f);
  numBytes += cDelay_init(this, &cDelay_8pZBTxkx, 0.0f);
  numBytes += hTable_init(&hTable_En7mSr3V, 256);
  numBytes += cTabhead_init(&cTabhead_mFYSAv8i, &hTable_En7mSr3V);
  numBytes += cVar_init_s(&cVar_q8KcnTP9, "del-1001-swell");
  numBytes += cDelay_init(this, &cDelay_CFRhCZXo, 8.0f);
  numBytes += cDelay_init(this, &cDelay_23vZxYiJ, 0.0f);
  numBytes += cBinop_init(&cBinop_5qSF4DEJ, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_GeE11NhS, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_HSNF0F5c, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_jrmhebEn, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_TLvsDXbe, 0.0f);
  numBytes += cDelay_init(this, &cDelay_m1iuuTgb, 0.0f);
  numBytes += hTable_init(&hTable_zGt13Z9v, 256);
  numBytes += cTabhead_init(&cTabhead_JFZvfewi, &hTable_zGt13Z9v);
  numBytes += cVar_init_s(&cVar_pGN57VFe, "del-1001-swell2");
  numBytes += cDelay_init(this, &cDelay_NuHipNip, 8.0f);
  numBytes += cDelay_init(this, &cDelay_zGZCshMv, 0.0f);
  numBytes += cBinop_init(&cBinop_Zti1Gsnh, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_DzDUWNM5, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_jrMJKvlH, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_3hwe6z8i, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_BOlAGIb3, 2.0f); // __sub
  numBytes += sVarf_init(&sVarf_Vy9LnoUE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8ioaRLxj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_c4NmG2oK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SCn4DCV2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9jBAcxSV, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_vSwellST::~Heavy_vSwellST() {
  sEnv_free(&sEnv_ef29TibG);
  cPack_free(&cPack_9BqThvxL);
  cPack_free(&cPack_Smm7eHNK);
  cPack_free(&cPack_2yxVP2h9);
  hTable_free(&hTable_En7mSr3V);
  hTable_free(&hTable_zGt13Z9v);
}

HvTable *Heavy_vSwellST::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xB4039215: return &hTable_En7mSr3V; // del-1001-swell
    case 0x505A9C79: return &hTable_zGt13Z9v; // del-1001-swell2
    default: return nullptr;
  }
}

void Heavy_vSwellST::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xCFF35931: { // Attack_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lv0OhOJ1_sendMessage);
      break;
    }
    case 0x4397AE0: { // Attack_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SW16PBUi_sendMessage);
      break;
    }
    case 0x73ACB90E: { // Mid_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AnC8fVTC_sendMessage);
      break;
    }
    case 0x4675584E: { // Mid_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_J1Dtw5zk_sendMessage);
      break;
    }
    case 0x558F437A: { // Release_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8VMuPHkm_sendMessage);
      break;
    }
    case 0x8D204657: { // Shape
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7iFwjdp5_sendMessage);
      break;
    }
    case 0x2D669F6F: { // SubEnv_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0mAQWHH6_sendMessage);
      break;
    }
    case 0x7BABB594: { // Threshold_High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6OACEwMi_sendMessage);
      break;
    }
    case 0xA0E82E9F: { // Threshold_Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MifnVdxX_sendMessage);
      break;
    }
    case 0x145892E8: { // Threshold_Strict
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RIxJwqZQ_sendMessage);
      break;
    }
    case 0xCB36B160: { // Trigger_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_crnVwkhl_sendMessage);
      break;
    }
    case 0x5DF5B524: { // Trigger_EXT
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_trRXEzvI_sendMessage);
      break;
    }
    case 0x4E6E7C40: { // Trigger_Left
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4vKBx25w_sendMessage);
      break;
    }
    case 0xB181ABB6: { // Trigger_Right
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xXvnwiDk_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZrCquMdt_sendMessage);
      break;
    }
    case 0x67E37CA3: { // __hv_notein
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iGatdiZ2_sendMessage);
      break;
    }
    case 0xA2F0F2D3: { // ecancel
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EK9WWhRv_sendMessage);
      break;
    }
    case 0xC698CFF8: { // subenv
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qP8RwIAn_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_vSwellST::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Attack_Level";
        info->hash = 0xCFF35931;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.6f;
        break;
      }
      case 1: {
        info->name = "Attack_ms";
        info->hash = 0x4397AE0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 3000.0f;
        info->defaultVal = 400.0f;
        break;
      }
      case 2: {
        info->name = "Mid_Level";
        info->hash = 0x73ACB90E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.65f;
        break;
      }
      case 3: {
        info->name = "Mid_ms";
        info->hash = 0x4675584E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 4: {
        info->name = "Release_ms";
        info->hash = 0x558F437A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 2200.0f;
        break;
      }
      case 5: {
        info->name = "Shape";
        info->hash = 0x8D204657;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.1f;
        info->maxVal = 3.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 6: {
        info->name = "SubEnv_Level";
        info->hash = 0x2D669F6F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1e-07f;
        info->maxVal = 0.7f;
        info->defaultVal = 1e-07f;
        break;
      }
      case 7: {
        info->name = "Threshold_High";
        info->hash = 0x7BABB594;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 20.0f;
        info->maxVal = 90.0f;
        info->defaultVal = 52.0f;
        break;
      }
      case 8: {
        info->name = "Threshold_Low";
        info->hash = 0xA0E82E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.3f;
        info->maxVal = 8.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 9: {
        info->name = "Threshold_Strict";
        info->hash = 0x145892E8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "Trigger_Delay";
        info->hash = 0xCB36B160;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 50.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 11: {
        info->name = "Trigger_EXT";
        info->hash = 0x5DF5B524;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Trigger_Left";
        info->hash = 0x4E6E7C40;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "Trigger_Right";
        info->hash = 0xB181ABB6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 14;
}



/*
 * Send Function Implementations
 */


void Heavy_vSwellST::sEnv_ef29TibG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jm7bDQku, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Jm7bDQku_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5rK7LGYk, HV_BINOP_LESS_THAN, 0, m, &cBinop_5rK7LGYk_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_6XPybnhd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_eezjNh03, 0, m, &cSlice_eezjNh03_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Eo2uFA79, 0, m, &cSlice_Eo2uFA79_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UOTEvinB_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MiEjAY2m_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_eezjNh03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_8XUJnGiv, 0, m, &cVar_8XUJnGiv_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_8XUJnGiv, 0, m, &cVar_8XUJnGiv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_Eo2uFA79_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_7MRcTODj, HV_BINOP_NEQ, 1, m, &cBinop_7MRcTODj_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_8XUJnGiv, 1, m, &cVar_8XUJnGiv_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_7MRcTODj, HV_BINOP_NEQ, 1, m, &cBinop_7MRcTODj_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_8XUJnGiv, 1, m, &cVar_8XUJnGiv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_8XUJnGiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Q7fImgHk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cIf_n2EK5mM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5ju61bn2_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eOhwLZXK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cCast_eOhwLZXK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8XUJnGiv, 0, m, &cVar_8XUJnGiv_sendMessage);
}

void Heavy_vSwellST::cCast_5ju61bn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7MRcTODj, HV_BINOP_NEQ, 1, m, &cBinop_7MRcTODj_sendMessage);
}

void Heavy_vSwellST::cBinop_7MRcTODj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n2EK5mM1, 1, m, &cIf_n2EK5mM1_sendMessage);
}

void Heavy_vSwellST::cCast_UOTEvinB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7MRcTODj, HV_BINOP_NEQ, 0, m, &cBinop_7MRcTODj_sendMessage);
}

void Heavy_vSwellST::cCast_MiEjAY2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n2EK5mM1, 0, m, &cIf_n2EK5mM1_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_BwzP3cHo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_oXgn5qED, 0, m, &cSlice_oXgn5qED_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_HrGIsvBs, 0, m, &cSlice_HrGIsvBs_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hcZtliCk_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VozY8R2V_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_oXgn5qED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_IAdyrz32, 0, m, &cVar_IAdyrz32_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_IAdyrz32, 0, m, &cVar_IAdyrz32_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_HrGIsvBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_dDRTG1e6, HV_BINOP_NEQ, 1, m, &cBinop_dDRTG1e6_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_IAdyrz32, 1, m, &cVar_IAdyrz32_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_dDRTG1e6, HV_BINOP_NEQ, 1, m, &cBinop_dDRTG1e6_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_IAdyrz32, 1, m, &cVar_IAdyrz32_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_IAdyrz32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0ooROSDh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cIf_67ROVOQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a257HhxY_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z9kw1Xip_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cCast_a257HhxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dDRTG1e6, HV_BINOP_NEQ, 1, m, &cBinop_dDRTG1e6_sendMessage);
}

void Heavy_vSwellST::cCast_Z9kw1Xip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IAdyrz32, 0, m, &cVar_IAdyrz32_sendMessage);
}

void Heavy_vSwellST::cBinop_dDRTG1e6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_67ROVOQQ, 1, m, &cIf_67ROVOQQ_sendMessage);
}

void Heavy_vSwellST::cCast_hcZtliCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dDRTG1e6, HV_BINOP_NEQ, 0, m, &cBinop_dDRTG1e6_sendMessage);
}

void Heavy_vSwellST::cCast_VozY8R2V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_67ROVOQQ, 0, m, &cIf_67ROVOQQ_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_Q7fImgHk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_71F2fAzP_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ucyFtQ2x_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_71F2fAzP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VJ4p4K4r, 0, m, &cVar_VJ4p4K4r_sendMessage);
}

void Heavy_vSwellST::cCast_ucyFtQ2x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZpWteOjJ_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bmabAoRR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dlUWFG9i_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_0ooROSDh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kPWcHP8t_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uJVNf0es_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_kPWcHP8t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vLtcr2oE, 0, m, &cVar_vLtcr2oE_sendMessage);
}

void Heavy_vSwellST::cCast_uJVNf0es_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aKXPAZH4_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_vLtcr2oE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jm7bDQku, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Jm7bDQku_sendMessage);
}

void Heavy_vSwellST::cVar_VJ4p4K4r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5rK7LGYk, HV_BINOP_LESS_THAN, 1, m, &cBinop_5rK7LGYk_sendMessage);
}

void Heavy_vSwellST::cBinop_Jm7bDQku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6XPybnhd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cBinop_5rK7LGYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BwzP3cHo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_ZpWteOjJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jm7bDQku, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Jm7bDQku_sendMessage);
}

void Heavy_vSwellST::cMsg_aKXPAZH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, -1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5rK7LGYk, HV_BINOP_LESS_THAN, 1, m, &cBinop_5rK7LGYk_sendMessage);
}

void Heavy_vSwellST::cSlice_lBaZtCwz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_bqqPPYbT_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_iy8MI4y8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_oOI1BQnd, 0, m, &cIf_oOI1BQnd_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_auNRyOoz, 0, m, &cIf_auNRyOoz_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_clcmUKHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_pU9sITTa, 0, m, &cIf_pU9sITTa_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_GNKHeRXH, 0, m, &cIf_GNKHeRXH_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_P5uwOQZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_1cBZY5ig_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_VP9p7aro, 0, m, &cIf_VP9p7aro_sendMessage);
}

void Heavy_vSwellST::cUnop_Zac7LjR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mfCj5LmC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PzQMmVos, HV_BINOP_EQ, 1, m, &cBinop_PzQMmVos_sendMessage);
}

void Heavy_vSwellST::cUnop_aXmnjREK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mfCj5LmC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PzQMmVos, HV_BINOP_EQ, 1, m, &cBinop_PzQMmVos_sendMessage);
}

void Heavy_vSwellST::cIf_VP9p7aro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_aXmnjREK_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_Zac7LjR4_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_1cBZY5ig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VP9p7aro, 1, m, &cIf_VP9p7aro_sendMessage);
}

void Heavy_vSwellST::cIf_auNRyOoz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ipAniNFU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_GNKHeRXH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_oOI1BQnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ipAniNFU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_pU9sITTa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_bqqPPYbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PzQMmVos, HV_BINOP_EQ, 0, m, &cBinop_PzQMmVos_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_F9DKBWNX_sendMessage);
}

void Heavy_vSwellST::cBinop_mfCj5LmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4A4YoYcw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LJ1Q04c5_sendMessage);
}

void Heavy_vSwellST::cBinop_PzQMmVos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lmg9L0OA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6yBLubeg_sendMessage);
}

void Heavy_vSwellST::cCast_6yBLubeg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pU9sITTa, 1, m, &cIf_pU9sITTa_sendMessage);
}

void Heavy_vSwellST::cCast_Lmg9L0OA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_auNRyOoz, 1, m, &cIf_auNRyOoz_sendMessage);
}

void Heavy_vSwellST::cCast_LJ1Q04c5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GNKHeRXH, 1, m, &cIf_GNKHeRXH_sendMessage);
}

void Heavy_vSwellST::cCast_4A4YoYcw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oOI1BQnd, 1, m, &cIf_oOI1BQnd_sendMessage);
}

void Heavy_vSwellST::cBinop_F9DKBWNX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_vSwellST::cSwitchcase_MwNPj1Yo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_O664obNq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_O664obNq_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5cakV7JD, 1, m, &cDelay_5cakV7JD_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BiMHNoKR_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_5cakV7JD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5cakV7JD, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yxbjUwmC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0IWOfYmS_sendMessage);
  cSwitchcase_NVyNat7M_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_O664obNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5cakV7JD, 0, m, &cDelay_5cakV7JD_sendMessage);
}

void Heavy_vSwellST::cCast_BiMHNoKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5cakV7JD, 0, m, &cDelay_5cakV7JD_sendMessage);
}

void Heavy_vSwellST::cPack_9BqThvxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3C8xqBZn_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_O7b3QRmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VIWsuJbL_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_dV8437cY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_MwNPj1Yo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_gQ35lEE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_9BqThvxL, 0, m, &cPack_9BqThvxL_sendMessage);
}

void Heavy_vSwellST::cCast_2rcBHhnQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_O7b3QRmX, 0, m, &cVar_O7b3QRmX_sendMessage);
}

void Heavy_vSwellST::cMsg_VIWsuJbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_pBq7F1MT, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_3C8xqBZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_pBq7F1MT, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_NVyNat7M_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_IIzrHNsW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_IIzrHNsW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_MzfkuPVe, 1, m, &cDelay_MzfkuPVe_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MiTxhbef_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_MzfkuPVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MzfkuPVe, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EVQCdmWU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8RgXuFHa_sendMessage);
  cSwitchcase_DLwmoRcU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_IIzrHNsW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MzfkuPVe, 0, m, &cDelay_MzfkuPVe_sendMessage);
}

void Heavy_vSwellST::cCast_MiTxhbef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MzfkuPVe, 0, m, &cDelay_MzfkuPVe_sendMessage);
}

void Heavy_vSwellST::cPack_Smm7eHNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CTEree51_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_IBZry0jz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rVEPyOya_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_jPP4D47F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_NVyNat7M_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_0IWOfYmS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_Smm7eHNK, 0, m, &cPack_Smm7eHNK_sendMessage);
}

void Heavy_vSwellST::cCast_yxbjUwmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IBZry0jz, 0, m, &cVar_IBZry0jz_sendMessage);
}

void Heavy_vSwellST::cMsg_rVEPyOya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_pBq7F1MT, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_CTEree51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_pBq7F1MT, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_DLwmoRcU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_HIxWMixu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_HIxWMixu_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_g3z2YjYP, 1, m, &cDelay_g3z2YjYP_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zXZKM7V8_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_g3z2YjYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_g3z2YjYP, m);
}

void Heavy_vSwellST::cMsg_HIxWMixu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_g3z2YjYP, 0, m, &cDelay_g3z2YjYP_sendMessage);
}

void Heavy_vSwellST::cCast_zXZKM7V8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_g3z2YjYP, 0, m, &cDelay_g3z2YjYP_sendMessage);
}

void Heavy_vSwellST::cPack_2yxVP2h9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eyHLqnlx_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_WLTUsyeT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_941Mdou4_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_CK8rsKPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_DLwmoRcU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_EVQCdmWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WLTUsyeT, 0, m, &cVar_WLTUsyeT_sendMessage);
}

void Heavy_vSwellST::cCast_8RgXuFHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_2yxVP2h9, 0, m, &cPack_2yxVP2h9_sendMessage);
}

void Heavy_vSwellST::cMsg_941Mdou4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_pBq7F1MT, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_eyHLqnlx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_pBq7F1MT, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_LIzv0Jg3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KlIK1OQV_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_KlIK1OQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bmabAoRR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dlUWFG9i_sendMessage);
}

void Heavy_vSwellST::cVar_PjgkuLcu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_szYyyJR5_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_QvApkUNX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_2yxVP2h9, 1, m, &cPack_2yxVP2h9_sendMessage);
}

void Heavy_vSwellST::cMsg_fT165trh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VHtc3phY_sendMessage);
}

void Heavy_vSwellST::cSystem_VHtc3phY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QAPJoy2S, HV_BINOP_MULTIPLY, 1, m, &cBinop_QAPJoy2S_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_lPK3ofP2, HV_BINOP_MULTIPLY, 1, m, &cBinop_lPK3ofP2_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_BlL7sMq7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_Iu0keMap_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_Iu0keMap_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XOVjpxrE_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_XpkycLab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XpkycLab, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XpkycLab, 0, m, &cDelay_XpkycLab_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_W7afLeXM, 0, m, &cVar_W7afLeXM_sendMessage);
}

void Heavy_vSwellST::cCast_XOVjpxrE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Iu0keMap_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XpkycLab, 0, m, &cDelay_XpkycLab_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_W7afLeXM, 0, m, &cVar_W7afLeXM_sendMessage);
}

void Heavy_vSwellST::cMsg_K0AJ6e2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6de217ZF_sendMessage);
}

void Heavy_vSwellST::cSystem_6de217ZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_gWIWbDpo_sendMessage);
}

void Heavy_vSwellST::cVar_tiGpKop4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N7Fu4iSp, HV_BINOP_MULTIPLY, 0, m, &cBinop_N7Fu4iSp_sendMessage);
}

void Heavy_vSwellST::cMsg_Iu0keMap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_XpkycLab, 0, m, &cDelay_XpkycLab_sendMessage);
}

void Heavy_vSwellST::cBinop_2nkl54pa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XpkycLab, 2, m, &cDelay_XpkycLab_sendMessage);
}

void Heavy_vSwellST::cBinop_gWIWbDpo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N7Fu4iSp, HV_BINOP_MULTIPLY, 1, m, &cBinop_N7Fu4iSp_sendMessage);
}

void Heavy_vSwellST::cBinop_N7Fu4iSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_2nkl54pa_sendMessage);
}

void Heavy_vSwellST::cVar_W7afLeXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kMHSrlSn, HV_BINOP_SUBTRACT, 0, m, &cBinop_kMHSrlSn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_LESS_THAN_EQL, 0.0f, 0, m, &cBinop_vivFwLZy_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_49adpw7S_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yV4aG8CC_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oUxG3B8v_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_yV4aG8CC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sRWWnp7j, 0, m, &cVar_sRWWnp7j_sendMessage);
}

void Heavy_vSwellST::cCast_oUxG3B8v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_njoE9gh6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NeEbI6tR_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_u95m6Cvg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hQh495rv, 0, m, &cSlice_hQh495rv_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_z7aEC4Ne, 0, m, &cSlice_z7aEC4Ne_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HTEgtk8O_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_neB6MhMy, 0, m, &cSlice_neB6MhMy_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_a5nUNzl5, 0, m, &cSlice_a5nUNzl5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mcWqDMID_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5UKRYAah_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_hQh495rv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_pVtS1QJg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cMsg_pVtS1QJg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_z7aEC4Ne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JJ5autNA_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_guemGqrY_sendMessage);
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JJ5autNA_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_guemGqrY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_GWewDSsR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I2Cmp03A_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EipaKL4p_sendMessage);
}

void Heavy_vSwellST::cVar_rdjMHrbs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NHoiDPHt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_NHoiDPHt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_25zCsDVs_sendMessage);
      break;
    }
    default: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_QAPJoy2S, HV_BINOP_MULTIPLY, 0, m, &cBinop_QAPJoy2S_sendMessage);
      cBinop_onMessage(_c, &Context(_c)->cBinop_YekjLSIg, HV_BINOP_DIVIDE, 1, m, &cBinop_YekjLSIg_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_tiGpKop4, 0, m, &cVar_tiGpKop4_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cCast_25zCsDVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3cm6B54S_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_duL4D7kA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O2jVewUs, HV_BINOP_SUBTRACT, 1, m, &cBinop_O2jVewUs_sendMessage);
}

void Heavy_vSwellST::cVar_hOU5BSWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sRWWnp7j, 0, m, &cVar_sRWWnp7j_sendMessage);
}

void Heavy_vSwellST::cVar_sRWWnp7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AxfnC6xF, HV_BINOP_ADD, 0, m, &cBinop_AxfnC6xF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UZhieM7x, HV_BINOP_ADD, 0, m, &cBinop_UZhieM7x_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_taCnmZ9g, m);
}

void Heavy_vSwellST::cSlice_neB6MhMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I2Cmp03A_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EipaKL4p_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_a5nUNzl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Gls0AbZQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_buqlnsXZ_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_Kw5tBYuh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W7afLeXM, 1, m, &cVar_W7afLeXM_sendMessage);
}

void Heavy_vSwellST::cBinop_lPK3ofP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Kw5tBYuh_sendMessage);
}

void Heavy_vSwellST::cBinop_QAPJoy2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_royKINkJ_sendMessage);
}

void Heavy_vSwellST::cBinop_royKINkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kMHSrlSn, HV_BINOP_SUBTRACT, 1, m, &cBinop_kMHSrlSn_sendMessage);
}

void Heavy_vSwellST::cBinop_kMHSrlSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W7afLeXM, 1, m, &cVar_W7afLeXM_sendMessage);
}

void Heavy_vSwellST::cMsg_2nsS3uvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cSwitchcase_BlL7sMq7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_FkjNqhx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_BlL7sMq7_onMessage(_c, NULL, 0, m, NULL);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UZhieM7x, HV_BINOP_ADD, 1, m, &cBinop_UZhieM7x_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AxfnC6xF, HV_BINOP_ADD, 1, m, &cBinop_AxfnC6xF_sendMessage);
}

void Heavy_vSwellST::cBinop_vivFwLZy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_49adpw7S_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cBinop_AxfnC6xF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sRWWnp7j, 1, m, &cVar_sRWWnp7j_sendMessage);
}

void Heavy_vSwellST::cBinop_YekjLSIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4weB9V2n, HV_BINOP_DIVIDE, 1, m, &cBinop_4weB9V2n_sendMessage);
}

void Heavy_vSwellST::cBinop_4weB9V2n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UZhieM7x, HV_BINOP_ADD, 1, m, &cBinop_UZhieM7x_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AxfnC6xF, HV_BINOP_ADD, 1, m, &cBinop_AxfnC6xF_sendMessage);
}

void Heavy_vSwellST::cCast_I2Cmp03A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lPK3ofP2, HV_BINOP_MULTIPLY, 0, m, &cBinop_lPK3ofP2_sendMessage);
}

void Heavy_vSwellST::cCast_EipaKL4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YekjLSIg, HV_BINOP_DIVIDE, 0, m, &cBinop_YekjLSIg_sendMessage);
}

void Heavy_vSwellST::cCast_buqlnsXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O2jVewUs, HV_BINOP_SUBTRACT, 0, m, &cBinop_O2jVewUs_sendMessage);
}

void Heavy_vSwellST::cCast_Gls0AbZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hOU5BSWe, 1, m, &cVar_hOU5BSWe_sendMessage);
}

void Heavy_vSwellST::cCast_NeEbI6tR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hOU5BSWe, 0, m, &cVar_hOU5BSWe_sendMessage);
}

void Heavy_vSwellST::cCast_njoE9gh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FkjNqhx6_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_UZhieM7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_duL4D7kA, 0, m, &cVar_duL4D7kA_sendMessage);
}

void Heavy_vSwellST::cMsg_pVtS1QJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_BlL7sMq7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_q0NLVQ16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_GWewDSsR, 1, m, &cVar_GWewDSsR_sendMessage);
}

void Heavy_vSwellST::cMsg_3cm6B54S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 20.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_QAPJoy2S, HV_BINOP_MULTIPLY, 0, m, &cBinop_QAPJoy2S_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YekjLSIg, HV_BINOP_DIVIDE, 1, m, &cBinop_YekjLSIg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tiGpKop4, 0, m, &cVar_tiGpKop4_sendMessage);
}

void Heavy_vSwellST::cCast_guemGqrY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UuFryglJ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UZhieM7x, HV_BINOP_ADD, 0, m, &cBinop_UZhieM7x_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sRWWnp7j, 1, m, &cVar_sRWWnp7j_sendMessage);
}

void Heavy_vSwellST::cCast_JJ5autNA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pVtS1QJg_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_O2jVewUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4weB9V2n, HV_BINOP_DIVIDE, 0, m, &cBinop_4weB9V2n_sendMessage);
}

void Heavy_vSwellST::cCast_UuFryglJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FkjNqhx6_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_HTEgtk8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GWewDSsR, 0, m, &cVar_GWewDSsR_sendMessage);
}

void Heavy_vSwellST::cCast_5UKRYAah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q0NLVQ16_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_mcWqDMID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2nsS3uvL_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_EnobYME1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_NrtAiUsJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_NrtAiUsJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Oa2l53Uh, 1, m, &cDelay_Oa2l53Uh_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3lAf70vi_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_Oa2l53Uh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Oa2l53Uh, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2rcBHhnQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gQ35lEE0_sendMessage);
  cSwitchcase_MwNPj1Yo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_NrtAiUsJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Oa2l53Uh, 0, m, &cDelay_Oa2l53Uh_sendMessage);
}

void Heavy_vSwellST::cCast_3lAf70vi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Oa2l53Uh, 0, m, &cDelay_Oa2l53Uh_sendMessage);
}

void Heavy_vSwellST::cVar_2TwLomNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iKw658hB, HV_BINOP_MULTIPLY, 0, m, &cBinop_iKw658hB_sendMessage);
}

void Heavy_vSwellST::cMsg_tid6LLgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Wh5xuiTF_sendMessage);
}

void Heavy_vSwellST::cSystem_Wh5xuiTF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g0vteJyJ_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_iKw658hB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_rwBUqkqO_sendMessage);
}

void Heavy_vSwellST::cBinop_1g9l7Lw2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iKw658hB, HV_BINOP_MULTIPLY, 1, m, &cBinop_iKw658hB_sendMessage);
}

void Heavy_vSwellST::cMsg_g0vteJyJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_1g9l7Lw2_sendMessage);
}

void Heavy_vSwellST::cBinop_rwBUqkqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_fc8X2M7w_sendMessage);
}

void Heavy_vSwellST::cBinop_fc8X2M7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_iQJRmYY7_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_K9n7jQ75, m);
}

void Heavy_vSwellST::cBinop_iQJRmYY7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_4tBFDUFj, m);
}

void Heavy_vSwellST::cMsg_QVMgJfjF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pPciLRTj_sendMessage);
}

void Heavy_vSwellST::cSystem_pPciLRTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_afufHno9_sendMessage);
}

void Heavy_vSwellST::cDelay_3fJhzoVn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3fJhzoVn, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8pZBTxkx, 0, m, &cDelay_8pZBTxkx_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3fJhzoVn, 0, m, &cDelay_3fJhzoVn_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_HzXBUYcN, 1, m, NULL);
}

void Heavy_vSwellST::cDelay_8pZBTxkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8pZBTxkx, m);
  cMsg_vzzyC6Zp_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_E6wzC8oy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_sdgiAxHF_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cBinop_AWP8Ebu9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KjYdkyip_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::hTable_En7mSr3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_roZrFWxa_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3fJhzoVn, 2, m, &cDelay_3fJhzoVn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mtNxHiT7_sendMessage);
}

void Heavy_vSwellST::cMsg_KjYdkyip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_En7mSr3V, 0, m, &hTable_En7mSr3V_sendMessage);
}

void Heavy_vSwellST::cBinop_afufHno9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_AWP8Ebu9_sendMessage);
}

void Heavy_vSwellST::cMsg_vzzyC6Zp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_En7mSr3V, 0, m, &hTable_En7mSr3V_sendMessage);
}

void Heavy_vSwellST::cCast_mtNxHiT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3fJhzoVn, 0, m, &cDelay_3fJhzoVn_sendMessage);
}

void Heavy_vSwellST::cMsg_roZrFWxa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_8pZBTxkx, 2, m, &cDelay_8pZBTxkx_sendMessage);
}

void Heavy_vSwellST::cMsg_sdgiAxHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_HzXBUYcN, 1, m, NULL);
}

void Heavy_vSwellST::cTabhead_mFYSAv8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GeE11NhS, HV_BINOP_SUBTRACT, 0, m, &cBinop_GeE11NhS_sendMessage);
}

void Heavy_vSwellST::cMsg_mRPxGKCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_M7YwDU3z_sendMessage);
}

void Heavy_vSwellST::cSystem_M7YwDU3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_GhcE2DDx_sendMessage);
}

void Heavy_vSwellST::cVar_q8KcnTP9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wJ13tyK5_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cDelay_CFRhCZXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CFRhCZXo, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_23vZxYiJ, 0, m, &cDelay_23vZxYiJ_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_kIkdEv17, 0, m, &sTabread_kIkdEv17_sendMessage);
}

void Heavy_vSwellST::cDelay_23vZxYiJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_23vZxYiJ, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_kIkdEv17, 0, m, &sTabread_kIkdEv17_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_23vZxYiJ, 0, m, &cDelay_23vZxYiJ_sendMessage);
}

void Heavy_vSwellST::sTabread_kIkdEv17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_jrmhebEn, HV_BINOP_SUBTRACT, 0, m, &cBinop_jrmhebEn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_5qSF4DEJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HSNF0F5c, HV_BINOP_MAX, 0, m, &cBinop_HSNF0F5c_sendMessage);
}

void Heavy_vSwellST::cBinop_GhcE2DDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5qSF4DEJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_5qSF4DEJ_sendMessage);
}

void Heavy_vSwellST::cBinop_GeE11NhS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1r8ycsT9_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_kIkdEv17, 0, m, &sTabread_kIkdEv17_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Od8lQxQ7_sendMessage);
}

void Heavy_vSwellST::cSystem_RXFdx7Ih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jrmhebEn, HV_BINOP_SUBTRACT, 1, m, &cBinop_jrmhebEn_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_23vZxYiJ, 2, m, &cDelay_23vZxYiJ_sendMessage);
}

void Heavy_vSwellST::cMsg_wJ13tyK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RXFdx7Ih_sendMessage);
}

void Heavy_vSwellST::cMsg_1r8ycsT9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CFRhCZXo, 0, m, &cDelay_CFRhCZXo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_23vZxYiJ, 0, m, &cDelay_23vZxYiJ_sendMessage);
}

void Heavy_vSwellST::cMsg_kGzxCOww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_HSNF0F5c, HV_BINOP_MAX, 1, m, &cBinop_HSNF0F5c_sendMessage);
}

void Heavy_vSwellST::cBinop_HSNF0F5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GeE11NhS, HV_BINOP_SUBTRACT, 1, m, &cBinop_GeE11NhS_sendMessage);
}

void Heavy_vSwellST::cCast_Od8lQxQ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CFRhCZXo, 0, m, &cDelay_CFRhCZXo_sendMessage);
}

void Heavy_vSwellST::cBinop_CPSNN3jx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CFRhCZXo, 2, m, &cDelay_CFRhCZXo_sendMessage);
}

void Heavy_vSwellST::cBinop_jrmhebEn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_CPSNN3jx_sendMessage);
}

void Heavy_vSwellST::cCast_ENWilNkO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_q8KcnTP9, 0, m, &cVar_q8KcnTP9_sendMessage);
  cMsg_mRPxGKCn_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_mFYSAv8i, 0, m, &cTabhead_mFYSAv8i_sendMessage);
}

void Heavy_vSwellST::cMsg_Djc04Zpw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3gpz4zJn_sendMessage);
}

void Heavy_vSwellST::cSystem_3gpz4zJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_n4yvViyS_sendMessage);
}

void Heavy_vSwellST::cDelay_TLvsDXbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TLvsDXbe, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_m1iuuTgb, 0, m, &cDelay_m1iuuTgb_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TLvsDXbe, 0, m, &cDelay_TLvsDXbe_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ee3hRAYU, 1, m, NULL);
}

void Heavy_vSwellST::cDelay_m1iuuTgb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_m1iuuTgb, m);
  cMsg_I0EiI8WS_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_x6HQgLXU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_z2mkAbyY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cBinop_8MENX40l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fmBBm7G3_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::hTable_zGt13Z9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4mfrPmyH_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TLvsDXbe, 2, m, &cDelay_TLvsDXbe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UlElaUkr_sendMessage);
}

void Heavy_vSwellST::cMsg_fmBBm7G3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_zGt13Z9v, 0, m, &hTable_zGt13Z9v_sendMessage);
}

void Heavy_vSwellST::cBinop_n4yvViyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_8MENX40l_sendMessage);
}

void Heavy_vSwellST::cMsg_I0EiI8WS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_zGt13Z9v, 0, m, &hTable_zGt13Z9v_sendMessage);
}

void Heavy_vSwellST::cCast_UlElaUkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TLvsDXbe, 0, m, &cDelay_TLvsDXbe_sendMessage);
}

void Heavy_vSwellST::cMsg_4mfrPmyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_m1iuuTgb, 2, m, &cDelay_m1iuuTgb_sendMessage);
}

void Heavy_vSwellST::cMsg_z2mkAbyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ee3hRAYU, 1, m, NULL);
}

void Heavy_vSwellST::cTabhead_JFZvfewi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DzDUWNM5, HV_BINOP_SUBTRACT, 0, m, &cBinop_DzDUWNM5_sendMessage);
}

void Heavy_vSwellST::cMsg_6MFvujwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VLdMjkTF_sendMessage);
}

void Heavy_vSwellST::cSystem_VLdMjkTF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_AMaH2TO9_sendMessage);
}

void Heavy_vSwellST::cVar_pGN57VFe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lJdw6Gur_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cDelay_NuHipNip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NuHipNip, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zGZCshMv, 0, m, &cDelay_zGZCshMv_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_4qF4cmoB, 0, m, &sTabread_4qF4cmoB_sendMessage);
}

void Heavy_vSwellST::cDelay_zGZCshMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zGZCshMv, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_4qF4cmoB, 0, m, &sTabread_4qF4cmoB_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zGZCshMv, 0, m, &cDelay_zGZCshMv_sendMessage);
}

void Heavy_vSwellST::sTabread_4qF4cmoB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_3hwe6z8i, HV_BINOP_SUBTRACT, 0, m, &cBinop_3hwe6z8i_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_Zti1Gsnh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jrMJKvlH, HV_BINOP_MAX, 0, m, &cBinop_jrMJKvlH_sendMessage);
}

void Heavy_vSwellST::cBinop_AMaH2TO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zti1Gsnh, HV_BINOP_MULTIPLY, 0, m, &cBinop_Zti1Gsnh_sendMessage);
}

void Heavy_vSwellST::cBinop_DzDUWNM5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BmZ0appY_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_4qF4cmoB, 0, m, &sTabread_4qF4cmoB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H3pauphR_sendMessage);
}

void Heavy_vSwellST::cSystem_dGrVeHdV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3hwe6z8i, HV_BINOP_SUBTRACT, 1, m, &cBinop_3hwe6z8i_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zGZCshMv, 2, m, &cDelay_zGZCshMv_sendMessage);
}

void Heavy_vSwellST::cMsg_lJdw6Gur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dGrVeHdV_sendMessage);
}

void Heavy_vSwellST::cMsg_BmZ0appY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_NuHipNip, 0, m, &cDelay_NuHipNip_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zGZCshMv, 0, m, &cDelay_zGZCshMv_sendMessage);
}

void Heavy_vSwellST::cMsg_p6yS3fEW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_jrMJKvlH, HV_BINOP_MAX, 1, m, &cBinop_jrMJKvlH_sendMessage);
}

void Heavy_vSwellST::cBinop_jrMJKvlH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DzDUWNM5, HV_BINOP_SUBTRACT, 1, m, &cBinop_DzDUWNM5_sendMessage);
}

void Heavy_vSwellST::cCast_H3pauphR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NuHipNip, 0, m, &cDelay_NuHipNip_sendMessage);
}

void Heavy_vSwellST::cBinop_K9W2txSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NuHipNip, 2, m, &cDelay_NuHipNip_sendMessage);
}

void Heavy_vSwellST::cBinop_3hwe6z8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_K9W2txSG_sendMessage);
}

void Heavy_vSwellST::cCast_d08P9zQw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pGN57VFe, 0, m, &cVar_pGN57VFe_sendMessage);
  cMsg_6MFvujwd_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_JFZvfewi, 0, m, &cTabhead_JFZvfewi_sendMessage);
}

void Heavy_vSwellST::cUnop_6rGBbcWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_SCn4DCV2, m);
}

void Heavy_vSwellST::cCast_dlUWFG9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_EnobYME1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_bmabAoRR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dIovPV41_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PjgkuLcu, 0, m, &cVar_PjgkuLcu_sendMessage);
}

void Heavy_vSwellST::cCast_1M0zRwTl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BOlAGIb3, HV_BINOP_SUBTRACT, 0, m, &cBinop_BOlAGIb3_sendMessage);
}

void Heavy_vSwellST::cCast_rN5lQBSE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vLtcr2oE, 0, m, &cVar_vLtcr2oE_sendMessage);
}

void Heavy_vSwellST::cBinop_BOlAGIb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VJ4p4K4r, 0, m, &cVar_VJ4p4K4r_sendMessage);
}

void Heavy_vSwellST::cSend_dIovPV41_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EK9WWhRv_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_ipAniNFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LIzv0Jg3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_nzzBHxXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 25.0f);
  cSwitchcase_u95m6Cvg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_szYyyJR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 3.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pBq7F1MT, 0, m, NULL);
}

void Heavy_vSwellST::cSend_HZFeMgCS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qP8RwIAn_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_c9EHILB7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Oa2l53Uh, 1, m, &cDelay_Oa2l53Uh_sendMessage);
}

void Heavy_vSwellST::cBinop_9Nkn97fV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_6rGBbcWo_sendMessage);
}

void Heavy_vSwellST::cReceive_MifnVdxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BOlAGIb3, HV_BINOP_SUBTRACT, 1, m, &cBinop_BOlAGIb3_sendMessage);
}

void Heavy_vSwellST::cReceive_ZrCquMdt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K0AJ6e2I_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_tiGpKop4, 0, m, &cVar_tiGpKop4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_P5uwOQZo, 0, m, &cVar_P5uwOQZo_sendMessage);
  cMsg_fT165trh_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_duL4D7kA, 0, m, &cVar_duL4D7kA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rdjMHrbs, 0, m, &cVar_rdjMHrbs_sendMessage);
  cMsg_tid6LLgu_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_2TwLomNj, 0, m, &cVar_2TwLomNj_sendMessage);
  cMsg_QVMgJfjF_sendMessage(_c, 0, m);
  cMsg_Djc04Zpw_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_QvApkUNX, 0, m, &cVar_QvApkUNX_sendMessage);
  cMsg_kGzxCOww_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_q8KcnTP9, 0, m, &cVar_q8KcnTP9_sendMessage);
  cMsg_mRPxGKCn_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_mFYSAv8i, 0, m, &cTabhead_mFYSAv8i_sendMessage);
  cMsg_p6yS3fEW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_pGN57VFe, 0, m, &cVar_pGN57VFe_sendMessage);
  cMsg_6MFvujwd_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_JFZvfewi, 0, m, &cTabhead_JFZvfewi_sendMessage);
}

void Heavy_vSwellST::cReceive_iGatdiZ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSlice_onMessage(_c, &Context(_c)->cSlice_lBaZtCwz, 0, m, &cSlice_lBaZtCwz_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_iy8MI4y8, 0, m, &cSlice_iy8MI4y8_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_clcmUKHM, 0, m, &cSlice_clcmUKHM_sendMessage);
}

void Heavy_vSwellST::cReceive_7iFwjdp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Vy9LnoUE, m);
}

void Heavy_vSwellST::cReceive_EK9WWhRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dV8437cY_sendMessage(_c, 0, m);
  cMsg_jPP4D47F_sendMessage(_c, 0, m);
  cMsg_CK8rsKPt_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cReceive_trRXEzvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bmabAoRR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dlUWFG9i_sendMessage);
}

void Heavy_vSwellST::cReceive_lv0OhOJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IBZry0jz, 1, m, &cVar_IBZry0jz_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_9BqThvxL, 1, m, &cPack_9BqThvxL_sendMessage);
}

void Heavy_vSwellST::cReceive_SW16PBUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_9BqThvxL, 2, m, &cPack_9BqThvxL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5cakV7JD, 1, m, &cDelay_5cakV7JD_sendMessage);
}

void Heavy_vSwellST::cReceive_AnC8fVTC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_Smm7eHNK, 1, m, &cPack_Smm7eHNK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WLTUsyeT, 1, m, &cVar_WLTUsyeT_sendMessage);
}

void Heavy_vSwellST::cReceive_J1Dtw5zk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_Smm7eHNK, 2, m, &cPack_Smm7eHNK_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MzfkuPVe, 1, m, &cDelay_MzfkuPVe_sendMessage);
}

void Heavy_vSwellST::cReceive_8VMuPHkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_2yxVP2h9, 2, m, &cPack_2yxVP2h9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_g3z2YjYP, 1, m, &cDelay_g3z2YjYP_sendMessage);
}

void Heavy_vSwellST::cReceive_qP8RwIAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QvApkUNX, 1, m, &cVar_QvApkUNX_sendMessage);
  cMsg_nzzBHxXt_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PjgkuLcu, 1, m, &cVar_PjgkuLcu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_O7b3QRmX, 1, m, &cVar_O7b3QRmX_sendMessage);
}

void Heavy_vSwellST::cReceive_0mAQWHH6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HZFeMgCS_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cReceive_crnVwkhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 3.0f, 0, m, &cBinop_c9EHILB7_sendMessage);
}

void Heavy_vSwellST::cReceive_4vKBx25w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_8ioaRLxj, m);
}

void Heavy_vSwellST::cReceive_xXvnwiDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_c4NmG2oK, m);
}

void Heavy_vSwellST::cReceive_6OACEwMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1M0zRwTl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rN5lQBSE_sendMessage);
}

void Heavy_vSwellST::cReceive_RIxJwqZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_9Nkn97fV_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_9jBAcxSV, m);
}




/*
 * Context Process Implementation
 */

int Heavy_vSwellST::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_tabwrite_f(&sTabwrite_HzXBUYcN, VIf(I0));
    __hv_tabwrite_f(&sTabwrite_ee3hRAYU, VIf(I1));
    __hv_varread_f(&sVarf_8ioaRLxj, VOf(Bf0));
    __hv_varread_f(&sVarf_c4NmG2oK, VOf(Bf1));
    __hv_mul_f(VIf(I1), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_K9n7jQ75, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_4tBFDUFj, VOf(Bf1));
    __hv_rpole_f(&sRPole_1xo7QLB3, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_9jBAcxSV, VOf(Bf0));
    __hv_varread_f(&sVarf_SCn4DCV2, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf3), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf2));
    __hv_gt_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_sqrt_f(VIf(Bf3), VOf(Bf3));
    __hv_and_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf2), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_div_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_ef29TibG, VIf(Bf2), &sEnv_ef29TibG_sendMessage);
    __hv_tabread_f(&sTabread_4qF4cmoB, VOf(Bf2));
    __hv_line_f(&sLine_pBq7F1MT, VOf(Bf0));
    __hv_varread_f(&sVarf_Vy9LnoUE, VOf(Bf1));
    __hv_pow_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_taCnmZ9g, VOf(Bf0));
    __hv_max_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f);
    __hv_min_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));
    __hv_tabread_f(&sTabread_kIkdEv17, VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf1), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_vSwellST::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_vSwellST::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
