/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_VSWELLST_HPP_
#define _HEAVY_CONTEXT_VSWELLST_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlTabhead.h"
#include "HvSignalVar.h"
#include "HvControlIf.h"
#include "HvSignalDel1.h"
#include "HvControlCast.h"
#include "HvTable.h"
#include "HvControlPack.h"
#include "HvSignalLine.h"
#include "HvControlUnop.h"
#include "HvSignalEnvelope.h"
#include "HvControlSlice.h"
#include "HvControlSystem.h"
#include "HvControlVar.h"
#include "HvControlDelay.h"
#include "HvControlBinop.h"
#include "HvSignalTabwrite.h"
#include "HvSignalTabread.h"
#include "HvMath.h"
#include "HvSignalRPole.h"

class Heavy_vSwellST : public HeavyContext {

 public:
  Heavy_vSwellST(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_vSwellST();

  const char *getName() override { return "vSwellST"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        ATTACK_LEVEL = 0xCFF35931, // Attack_Level
        ATTACK_MS = 0x4397AE0, // Attack_ms
        MID_LEVEL = 0x73ACB90E, // Mid_Level
        MID_MS = 0x4675584E, // Mid_ms
        RELEASE_MS = 0x558F437A, // Release_ms
        SHAPE = 0x8D204657, // Shape
        SUBENV_LEVEL = 0x2D669F6F, // SubEnv_Level
        THRESHOLD_HIGH = 0x7BABB594, // Threshold_High
        THRESHOLD_LOW = 0xA0E82E9F, // Threshold_Low
        THRESHOLD_STRICT = 0x145892E8, // Threshold_Strict
        TRIGGER_DELAY = 0xCB36B160, // Trigger_Delay
        TRIGGER_EXT = 0x5DF5B524, // Trigger_EXT
        TRIGGER_LEFT = 0x4E6E7C40, // Trigger_Left
        TRIGGER_RIGHT = 0xB181ABB6, // Trigger_Right
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void sEnv_ef29TibG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_6XPybnhd_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_eezjNh03_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_Eo2uFA79_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8XUJnGiv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_n2EK5mM1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eOhwLZXK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5ju61bn2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7MRcTODj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UOTEvinB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MiEjAY2m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_BwzP3cHo_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_oXgn5qED_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_HrGIsvBs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IAdyrz32_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_67ROVOQQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a257HhxY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z9kw1Xip_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dDRTG1e6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hcZtliCk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VozY8R2V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Q7fImgHk_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_71F2fAzP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ucyFtQ2x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0ooROSDh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_kPWcHP8t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uJVNf0es_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vLtcr2oE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VJ4p4K4r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jm7bDQku_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5rK7LGYk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZpWteOjJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aKXPAZH4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_lBaZtCwz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_iy8MI4y8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_clcmUKHM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_P5uwOQZo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Zac7LjR4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_aXmnjREK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_VP9p7aro_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1cBZY5ig_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_auNRyOoz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_GNKHeRXH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_oOI1BQnd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_pU9sITTa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bqqPPYbT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mfCj5LmC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PzQMmVos_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6yBLubeg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Lmg9L0OA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LJ1Q04c5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4A4YoYcw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F9DKBWNX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MwNPj1Yo_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_5cakV7JD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O664obNq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BiMHNoKR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_9BqThvxL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_O7b3QRmX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dV8437cY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gQ35lEE0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2rcBHhnQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VIWsuJbL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3C8xqBZn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_NVyNat7M_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_MzfkuPVe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IIzrHNsW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MiTxhbef_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_Smm7eHNK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IBZry0jz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jPP4D47F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0IWOfYmS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yxbjUwmC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rVEPyOya_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CTEree51_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_DLwmoRcU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_g3z2YjYP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HIxWMixu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zXZKM7V8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_2yxVP2h9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WLTUsyeT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CK8rsKPt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EVQCdmWU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8RgXuFHa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_941Mdou4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eyHLqnlx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_LIzv0Jg3_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_KlIK1OQV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PjgkuLcu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QvApkUNX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fT165trh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_VHtc3phY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_BlL7sMq7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_XpkycLab_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XOVjpxrE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K0AJ6e2I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_6de217ZF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tiGpKop4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Iu0keMap_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2nkl54pa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gWIWbDpo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N7Fu4iSp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_W7afLeXM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_49adpw7S_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_yV4aG8CC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oUxG3B8v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_u95m6Cvg_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_hQh495rv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_z7aEC4Ne_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GWewDSsR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rdjMHrbs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_NHoiDPHt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_25zCsDVs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_duL4D7kA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hOU5BSWe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sRWWnp7j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_neB6MhMy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_a5nUNzl5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Kw5tBYuh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lPK3ofP2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QAPJoy2S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_royKINkJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kMHSrlSn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2nsS3uvL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FkjNqhx6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vivFwLZy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AxfnC6xF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YekjLSIg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4weB9V2n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_I2Cmp03A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EipaKL4p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_buqlnsXZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Gls0AbZQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NeEbI6tR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_njoE9gh6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UZhieM7x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pVtS1QJg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_q0NLVQ16_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3cm6B54S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_guemGqrY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JJ5autNA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O2jVewUs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UuFryglJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HTEgtk8O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5UKRYAah_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mcWqDMID_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_EnobYME1_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Oa2l53Uh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NrtAiUsJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3lAf70vi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2TwLomNj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tid6LLgu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Wh5xuiTF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iKw658hB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1g9l7Lw2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g0vteJyJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rwBUqkqO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fc8X2M7w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iQJRmYY7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QVMgJfjF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_pPciLRTj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_3fJhzoVn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_8pZBTxkx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_E6wzC8oy_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_AWP8Ebu9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_En7mSr3V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KjYdkyip_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_afufHno9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vzzyC6Zp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mtNxHiT7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_roZrFWxa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sdgiAxHF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_mFYSAv8i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mRPxGKCn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_M7YwDU3z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_q8KcnTP9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_CFRhCZXo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_23vZxYiJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_kIkdEv17_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5qSF4DEJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GhcE2DDx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GeE11NhS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_RXFdx7Ih_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wJ13tyK5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1r8ycsT9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kGzxCOww_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HSNF0F5c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Od8lQxQ7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CPSNN3jx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jrmhebEn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ENWilNkO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Djc04Zpw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_3gpz4zJn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_TLvsDXbe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_m1iuuTgb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_x6HQgLXU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_8MENX40l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_zGt13Z9v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fmBBm7G3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n4yvViyS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I0EiI8WS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UlElaUkr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4mfrPmyH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_z2mkAbyY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_JFZvfewi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6MFvujwd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_VLdMjkTF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pGN57VFe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_NuHipNip_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_zGZCshMv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_4qF4cmoB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zti1Gsnh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AMaH2TO9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DzDUWNM5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_dGrVeHdV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lJdw6Gur_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BmZ0appY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p6yS3fEW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jrMJKvlH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_H3pauphR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K9W2txSG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3hwe6z8i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_d08P9zQw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_6rGBbcWo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dlUWFG9i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bmabAoRR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1M0zRwTl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rN5lQBSE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BOlAGIb3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_dIovPV41_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ipAniNFU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nzzBHxXt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_szYyyJR5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_HZFeMgCS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c9EHILB7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9Nkn97fV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MifnVdxX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZrCquMdt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_iGatdiZ2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7iFwjdp5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_EK9WWhRv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_trRXEzvI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lv0OhOJ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_SW16PBUi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AnC8fVTC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_J1Dtw5zk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8VMuPHkm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qP8RwIAn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0mAQWHH6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_crnVwkhl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4vKBx25w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xXvnwiDk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6OACEwMi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RIxJwqZQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalTabwrite sTabwrite_HzXBUYcN;
  SignalTabwrite sTabwrite_ee3hRAYU;
  SignalRPole sRPole_1xo7QLB3;
  SignalEnvelope sEnv_ef29TibG;
  SignalTabread sTabread_4qF4cmoB;
  SignalLine sLine_pBq7F1MT;
  SignalTabread sTabread_kIkdEv17;
  ControlSlice cSlice_eezjNh03;
  ControlSlice cSlice_Eo2uFA79;
  ControlVar cVar_8XUJnGiv;
  ControlIf cIf_n2EK5mM1;
  ControlBinop cBinop_7MRcTODj;
  ControlSlice cSlice_oXgn5qED;
  ControlSlice cSlice_HrGIsvBs;
  ControlVar cVar_IAdyrz32;
  ControlIf cIf_67ROVOQQ;
  ControlBinop cBinop_dDRTG1e6;
  ControlVar cVar_vLtcr2oE;
  ControlVar cVar_VJ4p4K4r;
  ControlBinop cBinop_Jm7bDQku;
  ControlBinop cBinop_5rK7LGYk;
  ControlSlice cSlice_lBaZtCwz;
  ControlSlice cSlice_iy8MI4y8;
  ControlSlice cSlice_clcmUKHM;
  ControlVar cVar_P5uwOQZo;
  ControlIf cIf_VP9p7aro;
  ControlBinop cBinop_1cBZY5ig;
  ControlIf cIf_auNRyOoz;
  ControlIf cIf_GNKHeRXH;
  ControlIf cIf_oOI1BQnd;
  ControlIf cIf_pU9sITTa;
  ControlBinop cBinop_bqqPPYbT;
  ControlBinop cBinop_mfCj5LmC;
  ControlBinop cBinop_PzQMmVos;
  ControlBinop cBinop_F9DKBWNX;
  ControlDelay cDelay_5cakV7JD;
  ControlPack cPack_9BqThvxL;
  ControlVar cVar_O7b3QRmX;
  ControlDelay cDelay_MzfkuPVe;
  ControlPack cPack_Smm7eHNK;
  ControlVar cVar_IBZry0jz;
  ControlDelay cDelay_g3z2YjYP;
  ControlPack cPack_2yxVP2h9;
  ControlVar cVar_WLTUsyeT;
  ControlVar cVar_PjgkuLcu;
  ControlVar cVar_QvApkUNX;
  SignalVarf sVarf_taCnmZ9g;
  ControlDelay cDelay_XpkycLab;
  ControlVar cVar_tiGpKop4;
  ControlBinop cBinop_2nkl54pa;
  ControlBinop cBinop_gWIWbDpo;
  ControlBinop cBinop_N7Fu4iSp;
  ControlVar cVar_W7afLeXM;
  ControlSlice cSlice_hQh495rv;
  ControlSlice cSlice_z7aEC4Ne;
  ControlVar cVar_GWewDSsR;
  ControlVar cVar_rdjMHrbs;
  ControlVar cVar_duL4D7kA;
  ControlVar cVar_hOU5BSWe;
  ControlVar cVar_sRWWnp7j;
  ControlSlice cSlice_neB6MhMy;
  ControlSlice cSlice_a5nUNzl5;
  ControlBinop cBinop_Kw5tBYuh;
  ControlBinop cBinop_lPK3ofP2;
  ControlBinop cBinop_QAPJoy2S;
  ControlBinop cBinop_royKINkJ;
  ControlBinop cBinop_kMHSrlSn;
  ControlBinop cBinop_vivFwLZy;
  ControlBinop cBinop_AxfnC6xF;
  ControlBinop cBinop_YekjLSIg;
  ControlBinop cBinop_4weB9V2n;
  ControlBinop cBinop_UZhieM7x;
  ControlBinop cBinop_O2jVewUs;
  ControlDelay cDelay_Oa2l53Uh;
  ControlVar cVar_2TwLomNj;
  ControlBinop cBinop_iKw658hB;
  ControlBinop cBinop_1g9l7Lw2;
  SignalVarf sVarf_4tBFDUFj;
  ControlBinop cBinop_rwBUqkqO;
  ControlBinop cBinop_fc8X2M7w;
  ControlBinop cBinop_iQJRmYY7;
  SignalVarf sVarf_K9n7jQ75;
  ControlDelay cDelay_3fJhzoVn;
  ControlDelay cDelay_8pZBTxkx;
  ControlBinop cBinop_AWP8Ebu9;
  HvTable hTable_En7mSr3V;
  ControlBinop cBinop_afufHno9;
  ControlTabhead cTabhead_mFYSAv8i;
  ControlVar cVar_q8KcnTP9;
  ControlDelay cDelay_CFRhCZXo;
  ControlDelay cDelay_23vZxYiJ;
  ControlBinop cBinop_5qSF4DEJ;
  ControlBinop cBinop_GhcE2DDx;
  ControlBinop cBinop_GeE11NhS;
  ControlBinop cBinop_HSNF0F5c;
  ControlBinop cBinop_CPSNN3jx;
  ControlBinop cBinop_jrmhebEn;
  ControlDelay cDelay_TLvsDXbe;
  ControlDelay cDelay_m1iuuTgb;
  ControlBinop cBinop_8MENX40l;
  HvTable hTable_zGt13Z9v;
  ControlBinop cBinop_n4yvViyS;
  ControlTabhead cTabhead_JFZvfewi;
  ControlVar cVar_pGN57VFe;
  ControlDelay cDelay_NuHipNip;
  ControlDelay cDelay_zGZCshMv;
  ControlBinop cBinop_Zti1Gsnh;
  ControlBinop cBinop_AMaH2TO9;
  ControlBinop cBinop_DzDUWNM5;
  ControlBinop cBinop_jrMJKvlH;
  ControlBinop cBinop_K9W2txSG;
  ControlBinop cBinop_3hwe6z8i;
  ControlBinop cBinop_BOlAGIb3;
  ControlBinop cBinop_ipAniNFU;
  ControlBinop cBinop_c9EHILB7;
  ControlBinop cBinop_9Nkn97fV;
  SignalVarf sVarf_Vy9LnoUE;
  SignalVarf sVarf_8ioaRLxj;
  SignalVarf sVarf_c4NmG2oK;
  SignalVarf sVarf_SCn4DCV2;
  SignalVarf sVarf_9jBAcxSV;
};

#endif // _HEAVY_CONTEXT_VSWELLST_HPP_
